@@ -22,7 +22,7 @@ class accountingPeriods : public XWidget, public Ui::accountingPeriods
     Q_OBJECT
 
 public:
-    accountingPeriods(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    accountingPeriods(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~accountingPeriods();
 
 public slots:
