@@ -141,14 +141,16 @@ void accountingYearPeriods::sDelete()
     int result = deleteAccountingYear.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("deleteAccountingYearPeriod", result), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Accounting Year Period"),
+                             storedProcErrorLookup("deleteAccountingYearPeriod", result),
+                             __FILE__, __LINE__);
       return;
     }
     sFillList();
   }
-  else if (deleteAccountingYear.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Accounting Year Period"),
+                                deleteAccountingYear, __FILE__, __LINE__))
   {
-    systemError(this, deleteAccountingYear.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
@@ -164,14 +166,16 @@ void accountingYearPeriods::sClosePeriod()
     int result = closeAccountingYear.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("closeAccountingYearPeriod", result), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Closing Requested Period"),
+                             storedProcErrorLookup("closeAccountingYearPeriod", result),
+                             __FILE__, __LINE__);
       return;
     }
     sFillList();
   }
-  else if (closeAccountingYear.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Closing Requested Period"),
+                                closeAccountingYear, __FILE__, __LINE__))
   {
-    systemError(this, closeAccountingYear.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
@@ -187,16 +191,16 @@ void accountingYearPeriods::sOpenPeriod()
     int result = openAccountingYear.value("result").toInt();
     if (result < 0)
     {
-      systemError(this,
-                  storedProcErrorLookup("openAccountingYearPeriod", result),
-                  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Opening Requested Period"),
+                             storedProcErrorLookup("openAccountingYearPeriod", result),
+                             __FILE__, __LINE__);
       return;
     }
     sFillList();
   }
-  else if (openAccountingYear.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Opening Requested Period"),
+                                openAccountingYear, __FILE__, __LINE__))
   {
-    systemError(this, openAccountingYear.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
