@@ -14,6 +14,9 @@
 #include <QSqlError>
 #include <QVariant>
 
+#include "errorReporter.h"
+#include "guiErrorCheck.h"
+#include "printApOpenItem.h"
 #include "taxDetail.h"
 
 apOpenItem::apOpenItem(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
@@ -26,27 +29,34 @@ apOpenItem::apOpenItem(QWidget* parent, const char* name, bool modal, Qt::Window
   connect(_buttonBox,      SIGNAL(rejected()),                     this, SLOT(sClose()));
   connect(_terms,          SIGNAL(newID(int)),                     this, SLOT(sPopulateDueDate()));
   connect(_vend,           SIGNAL(newId(int)),                     this, SLOT(sPopulateVendInfo(int)));
+  connect(_amount,         SIGNAL(editingFinished()),              this, SLOT(sDetermineTaxAmount()));
+  connect(_taxzone,        SIGNAL(newID(int)),                     this, SLOT(sDetermineTaxAmount()));
   connect(_taxLit,         SIGNAL(leftClickedURL(const QString&)), this, SLOT(sTaxDetail()));
-  connect(_docNumber,      SIGNAL(textEdited(QString)),       this, SLOT(sReleaseNumber()));
+  connect(_docNumber,      SIGNAL(textEdited(QString)),            this, SLOT(sReleaseNumber()));
+  connect(_usePrepaid,     SIGNAL(toggled(bool)),                  this, SLOT(sToggleAccount()));
   connect(_amount,         SIGNAL(valueChanged()),                 this, SLOT(sCalcBalance()));
 
   _cAmount = 0.0;
   _apopenid = -1;
   _seqiss = 0;
 
+  _docType->append(0, tr("Credit Memo"), "C");
+  _docType->append(1, tr("Debit Memo"),  "D");
+  _docType->append(2, tr("Voucher"),     "V");
+
   _apapply->addColumn( tr("Type"),        _dateColumn, Qt::AlignCenter,true, "doctype");
   _apapply->addColumn( tr("Doc. #"),               -1, Qt::AlignLeft,  true, "docnumber");
   _apapply->addColumn( tr("Apply Date"),  _dateColumn, Qt::AlignCenter,true, "apapply_postdate");
   _apapply->addColumn( tr("Amount"),     _moneyColumn, Qt::AlignRight, true, "apapply_amount");
-  _apapply->addColumn( tr("Currency"),_currencyColumn, Qt::AlignLeft,  true, "currabbr");
+  _apapply->addColumn( tr("Currency"),_currencyColumn, Qt::AlignLeft,  !omfgThis->singleCurrency(), "currabbr");
 
-  if (omfgThis->singleCurrency())
-      _apapply->hideColumn("currabbr");
+  _printOnPost->setVisible(false);
 
   _terms->setType(XComboBox::APTerms);
   _journalNumber->setEnabled(false);
 
-  _altAccntid->setType(GLCluster::cRevenue | GLCluster::cExpense);
+  _accntId->setType(GLCluster::cRevenue | GLCluster::cExpense);
+  sToggleAccount();
 }
 
 apOpenItem::~apOpenItem()
@@ -71,16 +81,16 @@ enum SetResponse apOpenItem::set(const ParameterList &pParams)
     if (param.toString() == "creditMemo")
     {
       setWindowTitle(windowTitle() + tr(" - Enter Misc. Credit Memo"));
-      _docType->setCurrentIndex(0);
+      _docType->setCode("C");
       _status->setEnabled(false);
     }
     else if (param.toString() == "debitMemo")
     {
       setWindowTitle(windowTitle() + tr(" - Enter Misc. Debit Memo"));
-      _docType->setCurrentIndex(1);
+      _docType->setCode("D");
     }
     else if (param.toString() == "voucher")
-      _docType->setCurrentIndex(2);
+      _docType->setCode("V");
     else
       return UndefinedError;
 //  ToDo - better error return types
@@ -105,6 +115,7 @@ enum SetResponse apOpenItem::set(const ParameterList &pParams)
 
       _paid->clear();
       _buttonBox->button(QDialogButtonBox::Save)->setText(tr("Post"));
+      _printOnPost->setVisible(true);
       populateStatus();
     }
     else if (param.toString() == "edit")
@@ -118,11 +129,12 @@ enum SetResponse apOpenItem::set(const ParameterList &pParams)
       _docNumber->setEnabled(false);
       _poNumber->setEnabled(false);
       _journalNumber->setEnabled(false);
-      _amount->setCurrencyEditable(false);
+      _amount->setEnabled(false);
       _terms->setEnabled(false);
       _notes->setReadOnly(false);
-      _useAltPrepaid->setEnabled(false);
-      _altAccntid->setEnabled(false);
+      _usePrepaid->setEnabled(false);
+      _taxzone->setEnabled(false);
+      _accntId->setEnabled(false);
     }
     else if (param.toString() == "view")
     {
@@ -139,9 +151,10 @@ enum SetResponse apOpenItem::set(const ParameterList &pParams)
       _terms->setEnabled(false);
       _terms->setType(XComboBox::Terms);
       _notes->setReadOnly(true);
-      _useAltPrepaid->setEnabled(false);
-      _altAccntid->setEnabled(false);
+      _usePrepaid->setEnabled(false);
+      _accntId->setEnabled(false);
       _status->setEnabled(false);
+      _taxzone->setEnabled(false);
       _buttonBox->setStandardButtons(QDialogButtonBox::Close);
     }
   }
@@ -165,61 +178,38 @@ void apOpenItem::sSave()
   XSqlQuery saveOpenItem;
   if (_mode == cNew)
   {
-    if (!_docDate->isValid())
-    {
-      QMessageBox::critical( this, tr("Cannot Save A/P Memo"),
-                             tr("<p>You must enter a date for this A/P Memo "
-                                "before you may save it") );
-      _docDate->setFocus();
+    QList<GuiErrorCheck> errors;
+    errors << GuiErrorCheck(!_docDate->isValid(), _docDate,
+                            tr("<p>You must enter a Document Date for this A/P Memo "
+                               "before you may save it"))
+    << GuiErrorCheck(!_dueDate->isValid(), _dueDate,
+                     tr("<p>You must enter a Due Date for this A/P Memo "
+                        "before you may save it"))
+    << GuiErrorCheck(_amount->isZero(), _amount,
+                     tr("<p>You must enter an amount for this A/P Memo "
+                        "before you may save it"))
+    << GuiErrorCheck(_tax->localValue() > _amount->localValue(), _tax,
+                     tr("The tax amount may not be greater than the total A/P Memo amount."))
+    << GuiErrorCheck(!_usePrepaid->isChecked() && !_accntId->isValid(), _accntId,
+                     tr("<p>You must choose a valid Distribution "
+                        "Account Number for this A/P Memo before you "
+                        "may save it."))
+    ;
+    if (GuiErrorCheck::reportErrors(this, tr("Cannot Save A/P Memo"), errors))
       return;
-    }
-
-    if (!_dueDate->isValid())
-    {
-      QMessageBox::critical( this, tr("Cannot Save A/P Memo"),
-                             tr("<p>You must enter a date for this A/P Memo "
-                                "before you may save it") );
-      _dueDate->setFocus();
-      return;
-    }
-
-    if (_amount->isZero())
-    {
-      QMessageBox::critical( this, tr("Cannot Save A/P Memo"),
-                             tr("<p>You must enter an amount for this A/P Memo "
-                                "before you may save it") );
-      _amount->setFocus();
-      return;
-    }
-
-    if(_tax->localValue() > _amount->localValue())
-    {
-      QMessageBox::critical( this, tr("Cannot Save A/P Memo"),
-                             tr("The tax amount may not be greater than the total A/P Memo amount.") );
-      return;
-    }
-
-    if (_useAltPrepaid->isChecked() && (!_altAccntid->isValid()))
-    {
-      QMessageBox::critical( this, tr("Cannot Save A/P Memo"),
-                            tr("<p>You must choose a valid Alternate Prepaid "
-                               "Account Number for this A/P Memo before you "
-                               "may save it.") );
-      return;
-    }
-
+    
     QString tmpFunctionName;
     QString queryStr;
 
-    if (_docType->currentIndex() == 0)
+    if (_docType->code() == "C")
       tmpFunctionName = "createAPCreditMemo";
-    else if (_docType->currentIndex() == 1)
+    else if (_docType->code() == "D")
       tmpFunctionName = "createAPDebitMemo";
     else
     {
-      systemError(this,
-		  tr("Internal Error: _docType has an invalid document type %1")
-		  .arg(_docType->currentIndex()), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Cannot Save A/P Memo"),
+                           tr("Internal Error: _docType has an invalid document type of %1")
+                           .arg(_docType->currentIndex()), __FILE__, __LINE__);
       return;
     }
 
@@ -228,7 +218,7 @@ void apOpenItem::sSave()
 		      QString("fetchJournalNumber('AP-MISC')") : _journalNumber->text()) +
 	       ", :apopen_docnumber, :apopen_ponumber, :apopen_docdate,"
 	       "  :apopen_amount, :apopen_notes, :apopen_accnt_id,"
-	       "  :apopen_duedate, :apopen_terms_id, :curr_id ) AS result;";
+	       "  :apopen_duedate, :apopen_terms_id, :curr_id, :apopen_taxzone_id ) AS result;";
 	
     saveOpenItem.prepare(queryStr);
     saveOpenItem.bindValue(":vend_id", _vend->id());
@@ -254,8 +244,9 @@ void apOpenItem::sSave()
                "    apopen_amount=:apopen_amount,"
                "    apopen_terms_id=:apopen_terms_id, "
 	       "    apopen_notes=:apopen_notes, "
-	           "    apopen_curr_id=:curr_id, "
-		       "    apopen_status = :apopen_status "
+               "    apopen_curr_id=:curr_id, "
+	       "    apopen_status = :apopen_status, "
+               "    apopen_taxzone_id = :apopen_taxzone_id "
                "WHERE (apopen_id=:apopen_id);" );
   }
 
@@ -268,31 +259,20 @@ void apOpenItem::sSave()
   saveOpenItem.bindValue(":apopen_notes",   _notes->toPlainText());
   saveOpenItem.bindValue(":curr_id", _amount->id());
   saveOpenItem.bindValue(":apopen_terms_id", _terms->id());
+  if (_taxzone->isValid())
+    saveOpenItem.bindValue(":apopen_taxzone_id", _taxzone->id());
   QString temp;
   if (_status->id() == 1)
     temp = "O" ;
   else
 	temp = "H" ;
   saveOpenItem.bindValue(":apopen_status", temp);
-  if(_useAltPrepaid->isChecked())
-    saveOpenItem.bindValue(":apopen_accnt_id", _altAccntid->id());
+  if(!_usePrepaid->isChecked())
+    saveOpenItem.bindValue(":apopen_accnt_id", _accntId->id());
   else
     saveOpenItem.bindValue(":apopen_accnt_id", -1);
 
-  switch (_docType->currentIndex())
-  {
-    case 0:
-      saveOpenItem.bindValue(":apopen_doctype", "C");
-      break;
-
-    case 1:
-      saveOpenItem.bindValue(":apopen_doctype", "D");
-      break;
-
-    case 2:
-      saveOpenItem.bindValue(":apopen_doctype", "V");
-      break;
-  }
+  saveOpenItem.bindValue(":apopen_doctype", _docType->code());
 
   saveOpenItem.exec();
   if (saveOpenItem.first())
@@ -312,16 +292,51 @@ void apOpenItem::sSave()
       }
     }
   }
-  else if (saveOpenItem.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Cannot Create A/P Memo"),
+                                saveOpenItem, __FILE__, __LINE__))
   {
-    systemError(this, saveOpenItem.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
   if (_mode == cEdit)
+  {
+    if(_printOnPost->isChecked())
+      sPrintOnPost(_apopenid);
     done(_apopenid);
+  }
   else
+  {
+    if(_printOnPost->isChecked())
+    {
+      if (_docType->code() == "C")
+//    Credit Memo function returns journal# not apopenid so we have to go find it
+      {
+        XSqlQuery getCMid;
+        getCMid.prepare("SELECT apopen_id AS result FROM apopen "
+                        "WHERE ((apopen_doctype = 'C') "
+                        " AND (apopen_docnumber = :docnumber) "
+                        " AND (apopen_journalnumber = :journal));");
+        getCMid.bindValue(":docnumber", _docNumber->text());
+        getCMid.bindValue(":journal", saveOpenItem.value("result").toInt());
+        getCMid.exec();
+        if (ErrorReporter::error(QtCriticalMsg, this, tr("Returning apopenid"),
+                           getCMid, __FILE__, __LINE__))
+        {
+          return;
+        }
+        if (getCMid.first())
+        {
+          sPrintOnPost(getCMid.value("result").toInt());
+        }
+      }
+      else
+      {
+//      The Debit Memo returns apopenid so is fine
+        sPrintOnPost(saveOpenItem.value("result").toInt());
+      }
+    }
     done(saveOpenItem.value("result").toInt());
+  }
 }
 
 void apOpenItem::sClose()
@@ -351,6 +366,11 @@ void apOpenItem::sReleaseNumber()
   }
 }
 
+void apOpenItem::sToggleAccount()
+{
+  _accntId->setEnabled(!_usePrepaid->isChecked());
+}
+
 void apOpenItem::populate()
 {
   populateStatus();
@@ -361,7 +381,7 @@ void apOpenItem::populate()
              "       apopen_amount,   apopen_paid, "
              "       (apopen_amount - apopen_paid) AS f_balance,"
              "       apopen_terms_id, apopen_notes, apopen_accnt_id, "
-             "       apopen_curr_id, "
+             "       apopen_curr_id, apopen_taxzone_id, "
 			 "       CASE WHEN apopen_status ='O' THEN 1 "
              "         ELSE CASE WHEN apopen_status = 'H' THEN 2 "
              "         END "
@@ -390,8 +410,9 @@ void apOpenItem::populate()
     _paid->setLocalValue(populateOpenItem.value("apopen_paid").toDouble());
     _balance->setLocalValue(populateOpenItem.value("f_balance").toDouble());
     _terms->setId(populateOpenItem.value("apopen_terms_id").toInt());
-	if (populateOpenItem.value("apopen_status").toString() == "C")
-	{
+    _taxzone->setId(populateOpenItem.value("apopen_taxzone_id").toInt());
+    if (populateOpenItem.value("apopen_status").toString() == "C")
+    {
       QString status;
       status = " SELECT DISTINCT "
             " CASE WHEN apopen_status ='C' THEN 0 "
@@ -402,12 +423,12 @@ void apOpenItem::populate()
             " END AS status "
             " FROM apopen "
             " WHERE apopen_status <> '' " ;
-	  _status->populate(status, -1);
-	  _status->setEnabled(false);
-	}
-	_status->setId(populateOpenItem.value("status_id").toInt());
+          _status->populate(status, -1);
+          _status->setEnabled(false);
+    }
+    _status->setId(populateOpenItem.value("status_id").toInt());
 	
-	XSqlQuery selectpayment;
+    XSqlQuery selectpayment;
     selectpayment.prepare("SELECT * FROM apselect WHERE apselect_apopen_id = :apopen_id;");
     selectpayment.bindValue(":apopen_id", _apopenid);
     selectpayment.exec();
@@ -424,17 +445,12 @@ void apOpenItem::populate()
 
     if(!populateOpenItem.value("apopen_accnt_id").isNull() && populateOpenItem.value("apopen_accnt_id").toInt() != -1)
     {
-      _useAltPrepaid->setChecked(true);
-      _altAccntid->setId(populateOpenItem.value("apopen_accnt_id").toInt());
+      _usePrepaid->setChecked(false);
+      _accntId->setId(populateOpenItem.value("apopen_accnt_id").toInt());
     }
 
     QString docType = populateOpenItem.value("apopen_doctype").toString();
-    if (docType == "C")
-      _docType->setCurrentIndex(0);
-    else if (docType == "D")
-      _docType->setCurrentIndex(1);
-    else if (docType == "V")
-      _docType->setCurrentIndex(2);
+    _docType->setCode(docType);
 
     _cAmount = _amount->localValue();
 
@@ -478,12 +494,10 @@ void apOpenItem::populate()
     populateOpenItem.bindValue(":apopen_id", _apopenid);
     populateOpenItem.bindValue(":other", tr("Other"));
     populateOpenItem.exec();
-    if (populateOpenItem.lastError().type() != QSqlError::NoError)
-	systemError(this, populateOpenItem.lastError().databaseText(), __FILE__, __LINE__);
     _apapply->populate(populateOpenItem, true);
-    if (populateOpenItem.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Information"),
+                                  populateOpenItem, __FILE__, __LINE__))
     {
-      systemError(this, populateOpenItem.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
   }
@@ -493,7 +507,8 @@ void apOpenItem::sPopulateVendInfo(int vend_id)
 {
   XSqlQuery vendor;
   vendor.prepare("SELECT vend_curr_id,"
-                 "       vend_terms_id "
+                 "       vend_terms_id, "
+                 "       vend_taxzone_id "
                  "  FROM vendinfo"
                  " WHERE(vend_id = :vend_id);");
   vendor.bindValue(":vend_id", vend_id);
@@ -502,6 +517,7 @@ void apOpenItem::sPopulateVendInfo(int vend_id)
   {
     _amount->setId(vendor.value("vend_curr_id").toInt());
     _tax->setId(vendor.value("vend_curr_id").toInt());
+    _taxzone->setId(vendor.value("vend_taxzone_id").toInt());
     _terms->setId(vendor.value("vend_terms_id").toInt());
   }
 }
@@ -517,60 +533,77 @@ void apOpenItem::sPopulateDueDate()
     dueq.exec();
     if (dueq.first())
       _dueDate->setDate(dueq.value("duedate").toDate());
-    else if (dueq.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Setting Due Date"),
+                                  dueq, __FILE__, __LINE__))
     {
-      systemError(this, dueq.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
   }
 }
 
+void apOpenItem::sPrintOnPost(int temp_id)
+{
+  ParameterList params;
+  params.append("apopen_id", temp_id);
+
+  printApOpenItem newdlg(this, "", true);
+  if (newdlg.set(params) == NoError)
+    newdlg.exec();
+}
+
+bool apOpenItem::sInitializeMemo()
+{
+  XSqlQuery ap;
+  ap.prepare("SELECT nextval('apopen_apopen_id_seq') AS result;");
+  ap.exec();
+  if (ap.first())
+    _apopenid = ap.value("result").toInt();
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Initializing Memo"),
+                                  ap, __FILE__, __LINE__))
+    return false;
+  else
+    return false;
+    
+  ap.prepare("INSERT INTO apopen "
+    "( apopen_id, apopen_docdate, apopen_duedate, apopen_doctype, "
+    "  apopen_docnumber, apopen_curr_id, apopen_posted, apopen_amount ) "
+    "VALUES "
+    "( :apopen_id, :docDate, :dueDate, :docType, :docNumber, :currId, false, 0 ); ");
+  ap.bindValue(":apopen_id",_apopenid);
+  ap.bindValue(":docDate", _docDate->date());
+  ap.bindValue(":dueDate", _dueDate->date());
+  ap.bindValue(":docType", _docType->code() );
+  ap.bindValue(":docNumber", _docNumber->text());
+  ap.bindValue(":currId", _amount->id());
+  ap.exec();
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Initializing Memo"),
+                                  ap, __FILE__, __LINE__))
+  {
+    return false;
+  }
+
+  return true;
+}
+
 void apOpenItem::sTaxDetail()
 {
   XSqlQuery ap;
   if (_apopenid == -1)
   {
-    if (!_docDate->isValid() || !_dueDate->isValid())
-    {
-      QMessageBox::critical( this, tr("Cannot set tax amounts"),
-                             tr("You must enter document and due dates for this A/P Memo before you may set tax amounts.") );
-      _docDate->setFocus();
+
+    QList<GuiErrorCheck>errors;
+    errors<<GuiErrorCheck(!_docDate->isValid(), _docDate,
+                            tr("You must enter a document date for this A/P Memo before you may set tax amounts."))
+           <<GuiErrorCheck(!_dueDate->isValid(), _dueDate,
+                            tr("You must enter a due date for this A/P Memo before you may set tax amounts."))
+           <<GuiErrorCheck(_amount->isZero(), _amount,
+                            tr("You must enter an amount for this Payable Memo before you may set tax amounts."));
+
+    if(GuiErrorCheck::reportErrors(this,tr("Cannot Set Tax Amounts"),errors))
+        return;
+
+    if (!sInitializeMemo())
       return;
-    }
-    
-    ap.prepare("SELECT nextval('apopen_apopen_id_seq') AS result;");
-    ap.exec();
-    if (ap.first())
-      _apopenid = ap.value("result").toInt();
-    else if (ap.lastError().type() != QSqlError::NoError)
-    {
-      systemError(this, ap.lastError().databaseText(), __FILE__, __LINE__);
-      return;
-    }
-    else
-      return;
-    
-    ap.prepare("INSERT INTO apopen "
-      "( apopen_id, apopen_docdate, apopen_duedate, apopen_doctype, "
-      "  apopen_docnumber, apopen_curr_id, apopen_posted, apopen_amount ) "
-      "VALUES "
-      "( :apopen_id, :docDate, :dueDate, :docType, :docNumber, :currId, false, 0 ); ");
-    ap.bindValue(":apopen_id",_apopenid);
-    ap.bindValue(":docDate", _docDate->date());
-    ap.bindValue(":dueDate", _dueDate->date());
-    if (_docType->currentIndex())
-      ap.bindValue(":docType", "D" );
-    else
-      ap.bindValue(":docType", "C" );
-    ap.bindValue(":docNumber", _docNumber->text());
-    ap.bindValue(":currId", _amount->id());
-    ap.exec();
-    if (ap.lastError().type() != QSqlError::NoError)
-    {
-      ap.exec("ROLLBACK;");
-      systemError(this, ap.lastError().databaseText(), __FILE__, __LINE__);
-      return;
-    }
   }
   
   taxDetail newdlg(this, "", true);
@@ -590,7 +623,7 @@ void apOpenItem::sTaxDetail()
   params.append("display_type", "A");
   params.append("subtotal", _amount->localValue());
   params.append("adjustment");
-  if (_docType->currentIndex())
+  if (_docType->code() == "D")
     params.append("sense",-1);
   if (newdlg.set(params) == NoError)  
   {
@@ -603,18 +636,49 @@ void apOpenItem::sTaxDetail()
     taxq.exec();
     if (taxq.first())
     {
-      if (_docType->currentIndex())
+      if (_docType->code() == "D")
         _tax->setLocalValue(taxq.value("tax").toDouble() * -1);
       else
         _tax->setLocalValue(taxq.value("tax").toDouble());
     }
-    else if (taxq.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Setting Tax Amounts"),
+                                  taxq, __FILE__, __LINE__))
     {
-      systemError(this, taxq.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
   }
 }
+
+void apOpenItem::sDetermineTaxAmount()
+{
+  if (_mode != cNew)
+    return;
+
+  XSqlQuery ap;
+  if (_apopenid == -1)
+  {
+    if (!_docDate->isValid() || !_dueDate->isValid() || _amount->isZero())
+      return;
+    if (!sInitializeMemo())
+      return;
+  }
+  ap.prepare( "SELECT updatememotax(:source, :doctype, :apopen_id, :taxzone, :date, :curr, :amount) AS tax;" );
+
+  ap.bindValue(":source",    "AP");
+  ap.bindValue(":doctype",   _docType->code());
+  ap.bindValue(":apopen_id", _apopenid);
+  ap.bindValue(":taxzone",   _taxzone->id());
+  ap.bindValue(":date",      _tax->effective());
+  ap.bindValue(":curr",      _tax->id());
+  ap.bindValue(":amount",    _amount->localValue());
+  ap.exec();
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Returning AP Open Tax"),
+                           ap, __FILE__, __LINE__))
+    return;
+
+  if (ap.first())
+    _tax->setLocalValue(ap.value("tax").toDouble());
+}
  
 void apOpenItem::populateStatus()
 {
