@@ -1,7 +1,7 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2016 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
@@ -56,9 +56,9 @@ configureIM::configureIM(QWidget* parent, const char* name, bool /*modal*/, Qt::
 	    "WHERE (orderseq_name='ToNumber');" );
     if (configureconfigureIM.first())
       _toNextNum->setText(configureconfigureIM.value("tonumber").toString());
-    else if (configureconfigureIM.lastError().type() != QSqlError::NoError)
-      systemError(this, configureconfigureIM.lastError().databaseText(), __FILE__, __LINE__);
-
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Next Transfer Order Number"),
+                                  configureconfigureIM, __FILE__, __LINE__))
+      return;
     _enableToShipping->setChecked(_metrics->boolean("EnableTOShipping"));
     _transferOrderChangeLog->setChecked(_metrics->boolean("TransferOrderChangeLog"));
   }
@@ -126,8 +126,9 @@ configureIM::configureIM(QWidget* parent, const char* name, bool /*modal*/, Qt::
          "SELECT currval('shipment_number_seq') AS shipment_number;");
   if (configureconfigureIM.first())
     _nextShipmentNum->setText(configureconfigureIM.value("shipment_number"));
-  else if (configureconfigureIM.lastError().type() != QSqlError::NoError)
-    systemError(this, configureconfigureIM.lastError().databaseText(), __FILE__, __LINE__);
+  else
+    ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Inventory Settings"),
+                       configureconfigureIM, __FILE__, __LINE__);
 
   _kitInheritCOS->setChecked(_metrics->boolean("KitComponentInheritCOS"));
   _disallowReceiptExcess->setChecked(_metrics->boolean("DisallowReceiptExcessQty"));
@@ -161,6 +162,7 @@ configureIM::configureIM(QWidget* parent, const char* name, bool /*modal*/, Qt::
     _costStd->isChecked();
 
   _asOfQOH->setChecked(_metrics->boolean("EnableAsOfQOH"));
+  _preventNegInventory->setChecked(_metrics->boolean("DisallowNegativeInventory"));
   
   // Jobs at this time should always be checked and disabled
   // when this is changed in the future this should be replaced with
@@ -233,14 +235,16 @@ bool configureIM::sSave()
       int result = configureSave.value("result").toInt();
       if (result < 0)
       {
-        systemError(this, storedProcErrorLookup("setNextNumber", result), __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Inventory Settings"),
+                                 storedProcErrorLookup("setNextNumber", result),
+                                 __FILE__, __LINE__);
         _toNextNum->setFocus();
         return false;
       }
     }
-    else if (configureSave.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Inventory Settings"),
+                                  configureSave, __FILE__, __LINE__))
     {
-      systemError(this, configureSave.lastError().databaseText(), __FILE__, __LINE__);
       _toNextNum->setFocus();
       return false;
     }
@@ -285,9 +289,9 @@ bool configureIM::sSave()
   configureSave.prepare("SELECT setval('shipment_number_seq', :shipmentnumber);");
   configureSave.bindValue(":shipmentnumber", _nextShipmentNum->text().toInt());
   configureSave.exec();
-  if (configureSave.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Inventory Settings"),
+                                configureSave, __FILE__, __LINE__))
   {
-    systemError(this, configureSave.lastError().databaseText(), __FILE__, __LINE__);
     _nextShipmentNum->setFocus();
     return false;
   }
@@ -312,6 +316,7 @@ bool configureIM::sSave()
       return false;
   }
   _metrics->set("EnableAsOfQOH", _asOfQOH->isChecked());
+  _metrics->set("DisallowNegativeInventory", _preventNegInventory->isChecked());
 
   return true;
 }
