@@ -15,6 +15,7 @@
 #include <QSqlError>
 #include "storedProcErrorLookup.h"
 #include "guiclient.h"
+#include "errorReporter.h"
 
 configurePD::configurePD(QWidget* parent, const char* name, bool /*modal*/, Qt::WindowFlags fl)
     : XAbstractConfigure(parent, fl)
@@ -109,8 +110,10 @@ bool configurePD::sSave()
       configureSave.exec(rsql);
       if (configureSave.first() && (configureSave.value("result").toInt() < 0))
       {
-        systemError(this, storedProcErrorLookup("CreateRevision", configureSave.value("result").toInt()),
-            __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Period"),
+                                 storedProcErrorLookup("CreateRevision",
+                                 configureSave.value("result").toInt()),
+                                 __FILE__, __LINE__);
         _metrics->set("RevControl", false);
         return false;
       }
