@@ -151,9 +151,9 @@ void costCategory::sCheck()
 
       _category->setEnabled(false);
     }
-    else if (costCheck.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Creating New Cost Category"),
+                                  costCheck, __FILE__, __LINE__))
     {
-      systemError(this, costCheck.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
   }
@@ -223,7 +223,8 @@ void costCategory::sSave()
       _costcatid = costSave.value("costcat_id").toInt();
     else
     {
-      systemError(this, costSave.lastError().databaseText(), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Creating New Cost Category"),
+                                  costSave, __FILE__, __LINE__);
       return;
     }
 
@@ -282,9 +283,9 @@ void costCategory::sSave()
   if (_toLiabilityClearing->isValid())
     costSave.bindValue(":costcat_toliability_accnt_id", _toLiabilityClearing->id());
   costSave.exec();
-  if (costSave.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Cost Category Information"),
+                                costSave, __FILE__, __LINE__))
   {
-    systemError(this, costSave.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
@@ -324,9 +325,9 @@ void costCategory::populate()
 
     emit populated(_costcatid);
   }
-  else if (costpopulate.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Cost Category Information"),
+                                costpopulate, __FILE__, __LINE__))
   {
-    systemError(this, costpopulate.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
