@@ -17,6 +17,7 @@
 #include <QVariant>
 
 #include "storedProcErrorLookup.h"
+#include "errorReporter.h"
 
 #define DEBUG false
 
@@ -37,8 +38,6 @@ int creditCard::saveCreditCard(QWidget *parent,
                               bool ccActive)
 {
   XSqlQuery creditaveCreditCard;
-  bool everythingOK;
-  everythingOK = true;
   int mode = cNew;
   int seq = 0;
 
@@ -152,9 +151,9 @@ int creditCard::saveCreditCard(QWidget *parent,
     creditaveCreditCard.exec();
     if (creditaveCreditCard.first())
       cceditreturn = creditaveCreditCard.value("cc_back").toInt();
-    else if (creditaveCreditCard.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, parent, tr("Error Saving Credit Card"),
+                                  creditaveCreditCard, __FILE__, __LINE__))
     {
-      systemError(parent, creditaveCreditCard.lastError().databaseText(), __FILE__, __LINE__);
       return -2;
     }
   }
@@ -180,9 +179,9 @@ int creditCard::saveCreditCard(QWidget *parent,
     creditaveCreditCard.exec("SELECT NEXTVAL('ccard_ccard_id_seq') AS ccard_id;");
     if (creditaveCreditCard.first())
       ccId = creditaveCreditCard.value("ccard_id").toInt();
-    else if (creditaveCreditCard.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, parent, tr("Error Saving Credit Card"),
+                                  creditaveCreditCard, __FILE__, __LINE__))
     {
-      systemError(parent, creditaveCreditCard.lastError().databaseText(), __FILE__, __LINE__);
       return -2;
     }
 
@@ -191,9 +190,9 @@ int creditCard::saveCreditCard(QWidget *parent,
     creditaveCreditCard.exec();
     if (creditaveCreditCard.first())
       seq = creditaveCreditCard.value("ccard_seq").toInt();
-    else if (creditaveCreditCard.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, parent, tr("Error Saving Credit Card"),
+                                  creditaveCreditCard, __FILE__, __LINE__))
     {
-      systemError(parent, creditaveCreditCard.lastError().databaseText(), __FILE__, __LINE__);
       return -2;
     }
 
@@ -253,9 +252,9 @@ int creditCard::saveCreditCard(QWidget *parent,
   creditaveCreditCard.bindValue(":key", key);
   creditaveCreditCard.bindValue(":ccard_type", ccType);
   creditaveCreditCard.exec();
-  if (creditaveCreditCard.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, parent, tr("Error Saving Credit Card"),
+                                creditaveCreditCard, __FILE__, __LINE__))
   {
-    systemError(parent, creditaveCreditCard.lastError().databaseText(), __FILE__, __LINE__);
     return -2;
   }
 
@@ -268,9 +267,9 @@ int creditCard::saveCreditCard(QWidget *parent,
     creditaveCreditCard.bindValue(":key",          key);
     creditaveCreditCard.bindValue(":ccard_id",     ccId);
     creditaveCreditCard.exec();
-    if (creditaveCreditCard.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, parent, tr("Error Saving Credit Card"),
+                                  creditaveCreditCard, __FILE__, __LINE__))
     {
-      systemError(parent, creditaveCreditCard.lastError().databaseText(), __FILE__, __LINE__);
       return -2;
     }
   }
@@ -301,7 +300,6 @@ void creditCard::languageChange()
 }
 
 const char *_fundsTypes2[] = { "M", "V", "A", "D" };
-const int _fundsTypeCount2 = 4;
 
 enum SetResponse creditCard::set(const ParameterList &pParams)
 {
@@ -336,7 +334,8 @@ enum SetResponse creditCard::set(const ParameterList &pParams)
 
     }
     else if (cust.lastError().type() != QSqlError::NoError)
-      systemError(this, cust.lastError().databaseText(), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Credit Card Information"),
+                         cust, __FILE__, __LINE__);
 
     if (param.toString() == "new")
     {
@@ -506,9 +505,9 @@ void creditCard::populate()
         _fundsType2->setCurrentIndex(counter);
 
   }
-  else if (creditpopulate.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Credit Card Information"),
+                                creditpopulate, __FILE__, __LINE__))
   {
-    systemError(this, creditpopulate.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
