@@ -22,7 +22,7 @@ class customerTypeList : public XDialog, public Ui::customerTypeList
     Q_OBJECT
 
 public:
-    customerTypeList(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    customerTypeList(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~customerTypeList();
 
 public slots:
