@@ -35,6 +35,8 @@ public slots:
     virtual void sView();
     virtual void sOnHold();
     virtual void sOpen();
+    virtual void sPrintItem();
+    virtual void sApplyAPOpenCM();
 
 protected slots:
     virtual void languageChange();
