@@ -22,7 +22,7 @@ class dspAllocations : public display, public Ui::dspAllocations
     Q_OBJECT
 
 public:
-    dspAllocations(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspAllocations(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
