@@ -19,7 +19,7 @@ class dspBookings : public display
     Q_OBJECT
 
 public:
-    dspBookings(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspBookings(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 public slots:
     virtual enum SetResponse set( const ParameterList & pParams );
