@@ -20,7 +20,7 @@ class dspExpiredInventoryByClassCode : public display, public Ui::dspExpiredInve
     Q_OBJECT
 
 public:
-    dspExpiredInventoryByClassCode(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspExpiredInventoryByClassCode(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
