@@ -37,12 +37,10 @@ dspPricesByItem::dspPricesByItem(QWidget* parent, const char*, Qt::WindowFlags f
   list()->addColumn(tr("Customer/Customer Type"), -1, Qt::AlignLeft,   true,  "typename"  );
   list()->addColumn(tr("Qty. Break"),     _qtyColumn, Qt::AlignRight,  true,  "f_qtybreak" );
   list()->addColumn(tr("Price"),        _priceColumn, Qt::AlignRight,  true,  "price" );
-  list()->addColumn(tr("Currency"),  _currencyColumn, Qt::AlignLeft,   true,  "currConcat"  );
+  list()->addColumn(tr("Currency"),  _currencyColumn, Qt::AlignLeft,   !omfgThis->singleCurrency(),  "currConcat"  );
   list()->addColumn(tr("Cost"),          _costColumn, Qt::AlignRight,  true,  "f_cost" );
   list()->addColumn(tr("Margin"),       _prcntColumn, Qt::AlignRight,  true,  "f_margin" );
 
-  if (omfgThis->singleCurrency())
-    list()->hideColumn(CURR_COL);
   sHandleCosts(_showCosts->isChecked());
 
 }
@@ -72,6 +70,7 @@ void dspPricesByItem::sHandleCosts(bool pShowCosts)
 bool dspPricesByItem::setParams(ParameterList & params)
 {
   XSqlQuery dspetParams;
+  double list = 0.0;
   double cost = 0.0;
 
   if(!_item->isValid())
@@ -81,20 +80,24 @@ bool dspPricesByItem::setParams(ParameterList & params)
     return false;
   }
 
+  dspetParams.prepare( "SELECT listPrice(:item_id) AS list;");
+  dspetParams.bindValue(":item_id", _item->id());
+  dspetParams.exec();
+  if (dspetParams.first())
+    list = dspetParams.value("list").toDouble();
+  else
+    return false;
+
   if (_showCosts->isChecked())
   {
     if (_useStandardCosts->isChecked())
     {
-      dspetParams.prepare( "SELECT (stdCost(item_id) * iteminvpricerat(item_id)) AS cost "
-                 "FROM item "
-                 "WHERE (item_id=:item_id);");
+      dspetParams.prepare( "SELECT (stdCost(:item_id) * iteminvpricerat(:item_id)) AS cost;");
       params.append("standardCosts"); // report only?
     }
     else if (_useActualCosts->isChecked())
     {
-      dspetParams.prepare( "SELECT (actCost(item_id) * iteminvpricerat(item_id)) AS cost "
-                 "FROM item "
-                 "WHERE (item_id=:item_id);");
+      dspetParams.prepare( "SELECT (actCost(:item_id) * iteminvpricerat(:item_id)) AS cost;");
       params.append("actualCosts"); // report only?
     }
 
@@ -112,9 +115,12 @@ bool dspPricesByItem::setParams(ParameterList & params)
   params.append("shipToPattern", tr("Cust. Ship-To Pattern"));
   params.append("custType", tr("Cust. Type"));
   params.append("custTypePattern", tr("Cust. Type Pattern"));
+  params.append("shipZone",        tr("Shipping Zone"));
+  params.append("saleType",        tr("Sale Type"));
   params.append("sale", tr("Sale"));
   params.append("listPrice", tr("List Price"));
   params.append("item_id", _item->id());
+  params.append("list", list);
   params.append("cost", cost);
   if (_showCosts->isChecked())
     params.append("showCosts");
