@@ -18,7 +18,7 @@ class dspShipmentsByShipment : public dspShipmentsBase
     Q_OBJECT
 
 public:
-    dspShipmentsByShipment(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspShipmentsByShipment(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 };
 
