@@ -14,6 +14,7 @@
 #include <QVariant>
 
 #include <metasql.h>
+#include "errorReporter.h"
 
 freightBreakdown::freightBreakdown(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
   : XDialog(parent, name, modal, fl)
@@ -132,9 +133,9 @@ SetResponse freightBreakdown::set(const ParameterList& pParams)
   MetaSQLQuery mql(sql);
   freightet = mql.toQuery(params);
   _freight->populate(freightet);
-  if (freightet.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Freight Information"),
+                                freightet, __FILE__, __LINE__))
   {
-    systemError(this, freightet.lastError().databaseText(), __FILE__, __LINE__);
     return UndefinedError;
   }
 
