@@ -1,6 +1,7 @@
 // generated 2009-04-30
 // grep "public X[Dialog,Widget]" *.h | awk -F : '{print "#include \""$1"\""}' > getscreen_headerlist.h
 #include "absoluteCalendarItem.h"
+#include "account1099.h"
 #include "accountingPeriod.h"
 #include "accountingPeriods.h"
 #include "accountingYearPeriod.h"
@@ -77,6 +78,7 @@
 #include "configurePO.h"
 #include "configureSO.h"
 #include "configureSearchPath.h"
+#include "configureWF.h"
 #include "configureWO.h"
 #include "confirmAchOK.h"
 #include "contact.h"
@@ -248,6 +250,7 @@
 #include "dspSummarizedBOM.h"
 #include "dspSummarizedGLTransactions.h"
 #include "dspSummarizedSales.h"
+#include "dspTax1099.h"
 #include "dspTaxHistory.h"
 #include "dspTimePhasedAvailability.h"
 #include "dspTimePhasedBookings.h"
@@ -261,6 +264,7 @@
 #include "dspUninvoicedReceivings.h"
 #include "dspUnusedPurchasedItems.h"
 #include "dspUsageStatistics.h"
+#include "dspUserPrivileges.h"
 #include "dspValidLocationsByItem.h"
 #include "dspVendorAPHistory.h"
 #include "dspVoucherRegister.h"
@@ -367,6 +371,7 @@
 #include "itemUOM.h"
 #include "labelForm.h"
 #include "labelForms.h"
+#include "ledgerControl.h"
 #include "listRecurringInvoices.h"
 #include "locales.h"
 #include "location.h"
@@ -439,6 +444,7 @@
 #include "printPackingListBatchByShipvia.h"
 #include "printPackingList.h"
 #include "printPoForm.h"
+#include "printToForm.h"
 #include "printPurchaseOrder.h"
 #include "printPurchaseOrdersByAgent.h"
 #include "printRaForm.h"
@@ -457,7 +463,7 @@
 #include "profitCenters.h"
 #include "project.h"
 #include "projects.h"
-//#include "projectTypes.h"
+#include "projectTypes.h"
 #include "prospect.h"
 #include "prospects.h"
 #include "purchaseOrder.h"
@@ -513,6 +519,7 @@
 #include "salesOrder.h"
 #include "salesOrderInformation.h"
 #include "salesOrderItem.h"
+#include "salesOrderSimple.h"
 #include "salesRep.h"
 #include "salesReps.h"
 #include "saleType.h"
@@ -630,7 +637,6 @@
 #include "vendorPriceList.h"
 #include "vendorType.h"
 #include "vendorTypes.h"
-#include "vendorWorkBench.h"
 #include "viewCheckRun.h"
 #include "voidChecks.h"
 #include "voucher.h"
