@@ -21,7 +21,7 @@ class honorific : public XDialog, public Ui::honorific
     Q_OBJECT
 
 public:
-    honorific(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    honorific(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~honorific();
 
 public slots:
