@@ -22,7 +22,7 @@ class itemAlias : public XDialog, public Ui::itemAlias
     Q_OBJECT
 
 public:
-    itemAlias(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    itemAlias(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~itemAlias();
 
 public slots:
