@@ -1,7 +1,7 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2016 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
@@ -90,6 +90,7 @@
 
 #include <QApplication>
 #include <QFile>
+#include <QHash>
 #include <QImage>
 #include <QMessageBox>
 #include <QPixmap>
@@ -99,6 +100,8 @@
 #include <QTranslator>
 #if QT_VERSION < 0x050000
 #include <QHttp>
+#else
+#include <QUrlQuery>
 #endif
 #include <QUrl>
 
@@ -108,6 +111,7 @@
 #include "xtupleplugin.h"
 #include "xtupleproductkey.h"
 
+#include "createfiscalyear.h"
 #include "errorReporter.h"
 #include "login2.h"
 #include "currenciesDialog.h"
@@ -119,6 +123,9 @@
 #include "scripttoolbox.h"
 #include "xmainwindow.h"
 #include "checkForUpdates.h"
+#include "salesOrderSimple.h"
+#include "userPreferences.h"
+#include "xtNetworkRequestManager.h"
 
 #include "sysLocale.h"
 
@@ -138,20 +145,6 @@ extern void xTupleMessageOutput(QtMsgType type, const QMessageLogContext &contex
 #else
 extern void xTupleMessageOutput(QtMsgType type, const char *msg);
 #endif
-// helps determine which edition we're running & what splash screen to present
-struct editionDesc {
-  editionDesc(QString ed, QString splash, bool check, QString query)
-    : editionName(ed),
-      splashResource(splash),
-      shouldCheckLicense(check),
-      queryString(query)
-  {}
-
-  QString editionName;
-  QString splashResource;
-  bool    shouldCheckLicense;
-  QString queryString;
-};
 
 int main(int argc, char *argv[])
 {
@@ -217,7 +210,7 @@ int main(int argc, char *argv[])
       {
         haveUsername = true;
         havePasswd   = true;
-      } 
+      }
       else if (argument.contains("-enhancedAuth", Qt::CaseInsensitive))
       {
         haveEnhancedAuth = true;
@@ -276,7 +269,7 @@ int main(int argc, char *argv[])
 
     if (haveEnhancedAuth)
       params.append("enhancedAuth", _enhancedAuth);
-    
+
     if (_evaluation)
       params.append("evaluation");
 
@@ -303,199 +296,197 @@ int main(int argc, char *argv[])
   qApp->processEvents();
   _metrics = new Metrics();
 
-  // TODO: can/should we compose the splash screen on the fly from parts?
-  QList<editionDesc> edition;
-  edition << editionDesc( "Enterprise",     ":/images/splashEnterprise.png",        true,
-               "SELECT fetchMetricText('Application') = 'Standard' AND COUNT(*) = 4"
-               " FROM pkghead"
-               " WHERE pkghead_name IN ('xtmfg', 'xtprjaccnt', 'asset', 'assetdepn');" )
-          << editionDesc( "Manufacturing",  ":/images/splashMfgEdition.png",        true,
-               "SELECT fetchMetricText('Application') = 'Standard' AND COUNT(*) = 1"
-               " FROM pkghead"
-               " WHERE pkghead_name IN ('xtmfg');" )
-          << editionDesc( "Distribution",       ":/images/splashDistEdition.png",        true,
-               "SELECT fetchMetricText('Application') = 'Standard';" )
-          << editionDesc( "PostBooks",      ":/images/splashPostBooks.png",        true,
-               "SELECT fetchMetricText('Application') = 'PostBooks';" )
-  ;
+  // TODO: we should compose the splash screen on the fly from parts
+  QString edition("PostBooks");
+  QHash<QString, QString> splashMap;
+  splashMap.insert("Distribution",  ":/images/splashDistEdition.png");
+  splashMap.insert("Enterprise",    ":/images/splashEnterprise.png");
+  splashMap.insert("Manufacturing", ":/images/splashMfgEdition.png");
+  splashMap.insert("PostBooks",     ":/images/splashPostBooks.png");
+
+  XSqlQuery q("SELECT getEdition() AS result;");
+  if (q.first())
+  {
+    edition = q.value("result").toString();
+  }
+  else
+  {
+    edition = _metrics->value("Application");
+  }
+
+  qDebug() << edition;
+  _splash->setPixmap(QPixmap(splashMap[q.value("result").toString()]));
+
+  _Name = _Name.arg(edition);
+
+  _splash->showMessage(QObject::tr("Checking License Key"), SplashTextAlignment, SplashTextColor);
+  qApp->processEvents();
+
+  int cnt = 50000;
+  int tot = 50000;
 
   XSqlQuery metric;
-  int editionIdx;       // we'll use this after the loop
-  for (editionIdx = 0; editionIdx < edition.size(); editionIdx++)
+  metric.prepare("SELECT numOfDatabaseUsers(:appName) AS xt_client_count,"
+                 "       numOfServerUsers() as total_client_count;");
+  metric.bindValue(":appName", _ConnAppName);
+  metric.exec();
+  if(metric.first())
   {
-    metric.exec(edition[editionIdx].queryString);
-    if (metric.first() && metric.value(0).toBool())
-      break;
+    cnt = metric.value("xt_client_count").toInt();
+    tot = metric.value("total_client_count").toInt();
   }
-  if (editionIdx >= edition.size())
-    editionIdx = edition.size(); // default to PostBooks
-
-  _splash->setPixmap(QPixmap(edition[editionIdx].splashResource));
-  _Name = _Name.arg(edition[editionIdx].editionName);
-
-  if (edition[editionIdx].shouldCheckLicense)
+  else
   {
-    _splash->showMessage(QObject::tr("Checking License Key"), SplashTextAlignment, SplashTextColor);
-    qApp->processEvents();
-
-    int cnt = 50000;
-    int tot = 50000;
-
-    metric.prepare("SELECT numOfDatabaseUsers(:appName) AS xt_client_count,"
-                   "       numOfServerUsers() as total_client_count;");
-    metric.bindValue(":appName", _ConnAppName);
-    metric.exec();
-    if(metric.first())
-    {        
-      cnt = metric.value("xt_client_count").toInt();
-      tot = metric.value("total_client_count").toInt();
-    }
-    else
-    {
-      ErrorReporter::error(QtCriticalMsg, 0, QObject::tr("Error Counting Users"),
-                           metric, __FILE__, __LINE__);
-    }
-    metric.exec("SELECT packageIsEnabled('drupaluserinfo') AS result;");
-    bool xtweb = false;
-    if(metric.first())
-      xtweb = metric.value("result").toBool();
-    bool forceLimit = _metrics->boolean("ForceLicenseLimit");
-    bool forced = false;
-    bool checkPass = true;
-    bool checkLock = false;
-    bool expired   = false;
-    bool invalid   = false;
-    QString checkPassReason;
-    QString rkey = _metrics->value("RegistrationKey");
-    XTupleProductKey pkey(rkey);
-    QString application = _metrics->value("Application");
-    if(pkey.valid() && (pkey.version() == 1 || pkey.version() == 2 || pkey.version() == 3))
-    {
-      if(pkey.expiration() < QDate::currentDate())
-      {
-        checkPass = false;
-        checkPassReason = QObject::tr("<p>Your license has expired.");
-        if(!pkey.perpetual())
-        {
-          int daysTo = pkey.expiration().daysTo(QDate::currentDate());
-          if(daysTo > 30)
-          {
-            checkLock = true;
-            expired = true;
-            checkPassReason = QObject::tr("<p>Your xTuple license expired over 30 days ago, and this software will no longer function. Please contact xTuple immediately to reinstate your software.");
-          }
-          else
-            checkPassReason = QObject::tr("<p>Attention:  Your xTuple license has expired, and in %1 days this software will cease to function.  Please contact xTuple to arrange for license renewal.").arg(30 - daysTo);
-        }
-        else
-          expired = true;
-      }
-      else if(application == "PostBooks" && pkey.users() == 1)
-      {
-        if(pkey.users() < cnt)
-          {
-          checkPass = false;
-          checkPassReason = QObject::tr("<p>Multiple concurrent users of xTuple PostBooks require a license key. Please contact key@xtuple.com to request a free license key for your local installation, or sales@xtuple.com to purchase additional users in the xTuple Cloud Service. <p>Thank you.");
-          checkLock = forced = forceLimit;
-          }
-      }
-      else if(pkey.users() != 0 && (pkey.users() < cnt || (!xtweb && (pkey.users() * 2 < tot))))
-      {
-        if (pkey.users() < cnt) {
-            checkPassReason = QObject::tr("<p>You have exceeded the number of allowed concurrent xTuple users for your license.</p>");
-        } else {
-            checkPassReason = QObject::tr("<p>You have exceeded the number of allowed concurrent database connections for your license.</p>");
-        }
-
-        checkPass = false;
-        checkLock = forced = forceLimit;
-      }
-      else
-      {
-        int daysTo = QDate::currentDate().daysTo(pkey.expiration());
-        if(!pkey.perpetual() && daysTo <= 15)
-        {
-          checkPass = false;
-          checkPassReason = QObject::tr("<p>Please note: your xTuple license will expire in %1 days.  You should already have received your renewal invoice; please contact xTuple at your earliest convenience.").arg(daysTo);
-        }
-      }
-    }
-    else
+    ErrorReporter::error(QtCriticalMsg, 0, QObject::tr("Error Counting Users"),
+                         metric, __FILE__, __LINE__);
+  }
+  metric.exec("SELECT packageIsEnabled('drupaluserinfo') AS result;");
+  bool xtweb = false;
+  if(metric.first())
+    xtweb = metric.value("result").toBool();
+  bool forceLimit = _metrics->boolean("ForceLicenseLimit");
+  bool forced = false;
+  bool checkPass = true;
+  bool checkLock = false;
+  bool expired   = false;
+  bool invalid   = false;
+  QString checkPassReason;
+  QString rkey = _metrics->value("RegistrationKey");
+  XTupleProductKey pkey(rkey);
+  QString application = _metrics->value("Application");
+  if(pkey.valid() && (pkey.version() == 1 || pkey.version() == 2 || pkey.version() == 3))
+  {
+    if(pkey.expiration() < QDate::currentDate())
     {
       checkPass = false;
-      invalid   = true;
-      checkPassReason = QObject::tr("<p>The Registration key installed for this system does not appear to be valid.");
-    }
-    if(!checkPass)
-    {
-      _splash->hide();
-      if (expired)
+      checkPassReason = QObject::tr("<p>Your license has expired.");
+      if(!pkey.perpetual())
       {
-        registrationKeyDialog newdlg(0, "", true);
-        if(newdlg.exec() == -1)
+        int daysTo = pkey.expiration().daysTo(QDate::currentDate());
+        if(daysTo > 30)
         {
-          QMessageBox::critical(0, QObject::tr("Registration Key"), checkPassReason);
-          return 0;
+          checkLock = true;
+          expired = true;
+          checkPassReason = QObject::tr("<p>Your xTuple license expired over 30 days ago, and this software will no longer function. Please contact xTuple immediately to reinstate your software.");
         }
-      }
-      else if(checkLock)
-      {
-        QMessageBox::critical(0, QObject::tr("Registration Key"), checkPassReason);
-        if(!forced)
-          return 0;
-      }
-      else if(invalid)
-      {
-        ParameterList params;
-        params.append("invalid");
-        registrationKeyDialog newdlg(0, "", true);
-        newdlg.set(params);
-        if(newdlg.exec() == -1)
-        {
-          QMessageBox::critical(0, QObject::tr("Registration Key"), checkPassReason);
-          return 0;
-        }        
+        else
+          checkPassReason = QObject::tr("<p>Attention:  Your xTuple license has expired, and in %1 days this software will cease to function.  Please contact xTuple to arrange for license renewal.").arg(30 - daysTo);
       }
       else
-      {
-        if(QMessageBox::critical(0, QObject::tr("Registration Key"), QObject::tr("%1\n<p>Would you like to continue anyway?").arg(checkPassReason), QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::No)
-          return 0;
-      }
-
-      if(forced)
-        checkPassReason.append(" FORCED!");
-
-      metric.exec("SELECT current_database() AS db;");
-      QString db = "";
-      QString dbname = _metrics->value("DatabaseName");
-      QString name   = _metrics->value("remitto_name");
-      if(metric.first())
-      {
-        db = metric.value("db").toString();
-      }
-
-#if QT_VERSION < 0x050000  // below removed in qt5, needs to be ported
-      QHttp *http = new QHttp();
-      QUrl url;
-      url.setUrl("https://www.xtuple.org//api/regviolation.php");
-      url.addQueryItem("key", QUrl::toPercentEncoding(rkey));
-      url.addQueryItem("error", QUrl::toPercentEncoding(checkPassReason));
-      url.addQueryItem("name", QUrl::toPercentEncoding(name));
-      url.addQueryItem("dbname", QUrl::toPercentEncoding(dbname));
-      url.addQueryItem("db", QUrl::toPercentEncoding(db));
-      url.addQueryItem("cnt", QString::number(cnt));
-      url.addQueryItem("tot", QString::number(tot));
-      url.addQueryItem("ver", _Version);
-
-      http->setHost("www.xtuple.org");
-      http->get(url.toString());
-      http->close();
-#endif
-      if(forced)
-        return 0;
-
-      _splash->show();
+        expired = true;
     }
+    else if(application == "PostBooks" && pkey.users() == 1)
+    {
+      if(pkey.users() < cnt)
+        {
+        checkPass = false;
+        checkPassReason = QObject::tr("<p>Multiple concurrent users of xTuple PostBooks require a license key. Please contact key@xtuple.com to request a free license key for your local installation, or sales@xtuple.com to purchase additional users in the xTuple Cloud Service. <p>Thank you.");
+        checkLock = forced = forceLimit;
+        }
+    }
+    else if(pkey.users() != 0 && (pkey.users() < cnt || (!xtweb && (pkey.users() * 2 < tot))))
+    {
+      if (pkey.users() < cnt) {
+          checkPassReason = QObject::tr("<p>You have exceeded the number of allowed concurrent xTuple users for your license.</p>");
+      } else {
+          checkPassReason = QObject::tr("<p>You have exceeded the number of allowed concurrent database connections for your license.</p>");
+      }
+
+      checkPass = false;
+      checkLock = forced = forceLimit;
+    }
+    else
+    {
+      int daysTo = QDate::currentDate().daysTo(pkey.expiration());
+      if(!pkey.perpetual() && daysTo <= 15)
+      {
+        checkPass = false;
+        checkPassReason = QObject::tr("<p>Please note: your xTuple license will expire in %1 days.  You should already have received your renewal invoice; please contact xTuple at your earliest convenience.").arg(daysTo);
+      }
+    }
+  }
+  else
+  {
+    checkPass = false;
+    invalid   = true;
+    checkPassReason = QObject::tr("<p>The Registration key installed for this system does not appear to be valid.");
+  }
+  if(!checkPass)
+  {
+    _splash->hide();
+    if (expired)
+    {
+      registrationKeyDialog newdlg(0, "", true);
+      if(newdlg.exec() == -1)
+      {
+        QMessageBox::critical(0, QObject::tr("Registration Key"), checkPassReason);
+        return 0;
+      }
+    }
+    else if(checkLock)
+    {
+      QMessageBox::critical(0, QObject::tr("Registration Key"), checkPassReason);
+      if(!forced)
+        return 0;
+    }
+    else if(invalid)
+    {
+      ParameterList params;
+      params.append("invalid");
+      registrationKeyDialog newdlg(0, "", true);
+      newdlg.set(params);
+      if(newdlg.exec() == -1)
+      {
+        QMessageBox::critical(0, QObject::tr("Registration Key"), checkPassReason);
+        return 0;
+      }
+    }
+    else
+    {
+      if(QMessageBox::critical(0, QObject::tr("Registration Key"), QObject::tr("%1\n<p>Would you like to continue anyway?").arg(checkPassReason), QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::No)
+        return 0;
+    }
+
+    if(forced)
+      checkPassReason.append(" FORCED!");
+
+    metric.exec("SELECT current_database() AS db;");
+    QString db = "";
+    QString dbname = _metrics->value("DatabaseName");
+    QString name   = _metrics->value("remitto_name");
+    if(metric.first())
+    {
+      db = metric.value("db").toString();
+    }
+#if QT_VERSION >= 0x050000
+    QUrlQuery urlQuery("https://www.xtuple.org/api/regviolation.php?");
+    urlQuery.addQueryItem("key", rkey);
+    urlQuery.addQueryItem("error", checkPassReason);
+    urlQuery.addQueryItem("name", name);
+    urlQuery.addQueryItem("dbname", dbname);
+    urlQuery.addQueryItem("db", db);
+    urlQuery.addQueryItem("cnt", QString::number(cnt));
+    urlQuery.addQueryItem("tot", QString::number(tot));
+    urlQuery.addQueryItem("ver", _Version);
+    QUrl url = urlQuery.query();
+#else
+    QUrl url;
+    url.setUrl("https://www.xtuple.org/api/regviolation.php");
+    url.addQueryItem("key", QUrl::toPercentEncoding(rkey));
+    url.addQueryItem("error", checkPassReason);
+    url.addQueryItem("name", name);
+    url.addQueryItem("dbname", dbname);
+    url.addQueryItem("db", QUrl::toPercentEncoding(db));
+    url.addQueryItem("cnt", QString::number(cnt));
+    url.addQueryItem("tot", QString::number(tot));
+    url.addQueryItem("ver", _Version);
+#endif
+    QMutex wait;
+    xtNetworkRequestManager _networkManager(url, wait);
+    if(forced)
+      return 0;
+
+    _splash->show();
   }
 
   QString _serverVersion = _metrics->value("ServerVersion");
@@ -562,7 +553,7 @@ int main(int argc, char *argv[])
       files << langq.value("locale_lang_file").toString();
 
     QString langext;
-    if (!langq.value("lang_abbr2").toString().isEmpty() && 
+    if (!langq.value("lang_abbr2").toString().isEmpty() &&
         !langq.value("country_abbr").toString().isEmpty())
     {
       langext = langq.value("lang_abbr2").toString() + "_" +
@@ -654,7 +645,7 @@ int main(int argc, char *argv[])
   QString keypath;
   QString keyname;
   QString keytogether;
-  
+
 #ifdef Q_OS_WIN
   keypath = _metrics->value("CCWinEncKey");
 #elif defined Q_OS_MAC
@@ -662,7 +653,7 @@ int main(int argc, char *argv[])
 #elif defined Q_OS_LINUX
   keypath = _metrics->value("CCLinEncKey");
 #endif
-  
+
   if (keypath.isEmpty())
     keypath = app.applicationDirPath();
 
@@ -678,9 +669,9 @@ int main(int argc, char *argv[])
     if(!kn.exists())
       keyname = "OpenMFG.key";
   }
-  
+
   keytogether = keypath + keyname;
-  
+
   // qDebug("keytogether: %s", keytogether.toLatin1().data());
   QFile keyFile(keytogether);
 
@@ -703,7 +694,7 @@ int main(int argc, char *argv[])
 	qApp->processEvents();
 	_metricsenc = new Metricsenc(key);
   }
-  
+
   initializePlugin(_preferences, _metrics, _privileges, omfgThis->username(), omfgThis->workspace());
 
 // START code for updating the locale settings if they haven't been already
@@ -756,6 +747,15 @@ int main(int argc, char *argv[])
       return -2;
     }
   }
+  else if (omfgThis->_singleWindow == "salesOrderSimple")
+  {
+    ParameterList params;
+    params.append("mode", "new");
+
+    salesOrderSimple *newdlg = new salesOrderSimple();
+    newdlg->set(params);
+    omfgThis->handleNewWindow(newdlg);
+  }
 
   // Check for the existance of a base currency, if none, one needs to
   // be selected or created
@@ -776,7 +776,8 @@ int main(int argc, char *argv[])
       }
       else
       {
-        systemError(0, baseCurrency.lastError().databaseText(), __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, omfgThis, QObject::tr("Error Retrieving Base Currency Information"),
+                             baseCurrency, __FILE__, __LINE__);
         // need to figure out appropriate return code for this...unusual error
         return -1;
       }
@@ -784,7 +785,8 @@ int main(int argc, char *argv[])
   }
   else
   {
-    systemError(0, baseCurrency.lastError().databaseText(), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, omfgThis, QObject::tr("Error Retrieving Base Currency Information"),
+                           baseCurrency, __FILE__, __LINE__);
     // need to figure out appropriate return code for this...unusual error
     return -1;
   }
@@ -814,17 +816,15 @@ int main(int argc, char *argv[])
 
 //  Check for valid current Fiscal period
   XSqlQuery periodCheck;
-  periodCheck.prepare("SELECT EXISTS(SELECT * FROM period "
+  periodCheck.prepare("SELECT EXISTS(SELECT 1 FROM period "
             "     WHERE ((current_date BETWEEN period_start AND period_end) "
-            "       AND (NOT period_closed))) AS result; ");
+            "       AND (NOT period_closed))) AS found; ");
   periodCheck.exec();
-  if(periodCheck.first() && periodCheck.value("result").toBool() != true)
-    QMessageBox::warning( omfgThis, QObject::tr("Additional Configuration Required"),
-      QObject::tr("<p>Your system does not have a valid or open Accounting period "
-                  "for the current date. "
-                  "You should define the Accounting periods in 'Accounting | "
-                  "Fiscal Calendar | Accounting Periods...' before posting any "
-                  "transactions in the system.") );
+  if(periodCheck.first() && ! periodCheck.value("found").toBool())
+  {
+    createFiscalYear newdlg(NULL);
+    (void)newdlg.exec();
+  }
 
 //  Check for valid current exchange rates
   XSqlQuery xrateCheck("SELECT curr_abbr"
@@ -839,6 +839,31 @@ int main(int argc, char *argv[])
                   "Setup | Exchange Rates...' before posting any "
                   "transactions in the system.") );
 
+// Check for presence of password reset requirement and user last reset days
+  XSqlQuery resetCheck("SELECT fetchmetricbool('EnforcePasswordReset') as passreset, "
+                       "       fetchmetricvalue('PasswordResetDays')::TEXT as resetdays, "
+                       "(SELECT current_date - fetchmetricvalue('PasswordResetDays')::INTEGER > "
+                       "(SELECT usrpref_value FROM usrpref WHERE ((usrpref_username = geteffectivextuser()) "
+                       " AND (usrpref_name = 'PasswordResetDate')))::DATE) AS lastreset;");
+  resetCheck.exec();
+  if(resetCheck.first())
+  {
+    if(resetCheck.value("passreset").toBool() && resetCheck.value("lastreset").toBool())
+    {
+      QMessageBox::warning( omfgThis, QObject::tr("New Password Required"),
+        QObject::tr("<p>Your company has a policy of updating passwords every %1 days.  "
+                  "Please change your password before logging out.").arg(resetCheck.value("resetdays").toString()));
+      if (_privileges->check("MaintainPreferencesSelf"))
+      {
+        ParameterList params;
+        params.append("passwordReset");
+        userPreferences newdlg(0, "", true);
+        newdlg.set(params);
+        newdlg.exec();
+      }
+    }
+  }
+
   app.exec();
 
 //  Clean up
