@@ -67,7 +67,6 @@
 
 #include "vendor.h"
 #include "vendors.h"
-#include "vendorWorkBench.h"
 
 #include "dspItemsWithoutItemSources.h"
 #include "assignItemToPlannerCode.h"
@@ -258,11 +257,7 @@ void menuPurchase::addActionsToMenu(actionProperties acts[], unsigned int numEle
   QAction * m = 0;
   for (unsigned int i = 0; i < numElems; i++)
   {
-    if (! acts[i].visible)
-    {
-      continue;
-    }
-    else if (acts[i].actionName == QString("menu"))
+    if (acts[i].actionName == QString("menu"))
     {
       m = acts[i].menu->addMenu((QMenu*)(acts[i].slot));
       if(m)
@@ -270,11 +265,11 @@ void menuPurchase::addActionsToMenu(actionProperties acts[], unsigned int numEle
     }
     else if (acts[i].actionName == QString("separator"))
     {
-      acts[i].menu->addSeparator();
+      m = acts[i].menu->addSeparator();
     }
     else if ((acts[i].toolBar != NULL) && (!acts[i].toolTip.isEmpty()))
     {
-      new Action( parent,
+      m = new Action( parent,
                   acts[i].actionName,
                   acts[i].actionTitle,
                   this,
@@ -287,7 +282,7 @@ void menuPurchase::addActionsToMenu(actionProperties acts[], unsigned int numEle
     }
     else if (acts[i].toolBar != NULL)
     {
-      new Action( parent,
+      m = new Action( parent,
                   acts[i].actionName,
                   acts[i].actionTitle,
                   this,
@@ -300,7 +295,7 @@ void menuPurchase::addActionsToMenu(actionProperties acts[], unsigned int numEle
     }
     else
     {
-      new Action( parent,
+      m = new Action( parent,
                   acts[i].actionName,
                   acts[i].actionTitle,
                   this,
@@ -308,6 +303,7 @@ void menuPurchase::addActionsToMenu(actionProperties acts[], unsigned int numEle
                   acts[i].menu,
                   acts[i].priv ) ;
     }
+    if (m) m->setVisible(acts[i].visible);
   }
 }
 
@@ -562,7 +558,15 @@ void menuPurchase::sVendors()
 
 void menuPurchase::sVendorWorkBench()
 {
-  omfgThis->handleNewWindow(new vendorWorkBench());
+  ParameterList params;
+  if (_privileges->check("MaintainVendors"))
+    params.append("mode", "edit");
+  else
+    params.append("mode", "view");
+  
+  vendor *newdlg = new vendor();
+  newdlg->set(params);
+  omfgThis->handleNewWindow(newdlg);
 }
 
 // Utilities
