@@ -15,6 +15,7 @@
 #include <QVariant>
 
 #include <openreports.h>
+#include "errorReporter.h"
 #include <metasql.h>
 
 #include "mqlutil.h"
@@ -34,6 +35,7 @@ openReturnAuthorizations::openReturnAuthorizations(QWidget* parent, const char*
   connect(_view, SIGNAL(clicked()), this, SLOT(sView()));
   connect(_ra, SIGNAL(valid(bool)), _view, SLOT(setEnabled(bool)));
   connect(_new, SIGNAL(clicked()), this, SLOT(sNew()));
+  connect(_closeRA, SIGNAL(clicked()), this, SLOT(sCloseRA()));
   connect(_delete, SIGNAL(clicked()), this, SLOT(sDelete()));
   connect(_expired, SIGNAL(clicked()), this, SLOT(sFillList()));
   connect(_unauthorized, SIGNAL(clicked()), this, SLOT(sFillList()));
@@ -49,6 +51,7 @@ openReturnAuthorizations::openReturnAuthorizations(QWidget* parent, const char*
   {
     connect(_ra, SIGNAL(valid(bool)), _edit, SLOT(setEnabled(bool)));
     connect(_ra, SIGNAL(valid(bool)), _delete, SLOT(setEnabled(bool)));
+    connect(_ra, SIGNAL(valid(bool)), _closeRA, SLOT(setEnabled(bool)));
     connect(_ra, SIGNAL(itemSelected(int)), _edit, SLOT(animateClick()));
   }
   else
@@ -153,6 +156,26 @@ void openReturnAuthorizations::sView()
   omfgThis->handleNewWindow(newdlg);
 }
 
+void openReturnAuthorizations::sCloseRA()
+{
+  XSqlQuery openClose;
+  if (!checkSitePrivs(_ra->id()))
+    return;
+
+  openClose.prepare("UPDATE raitem SET raitem_status = 'C' "
+                    "WHERE ((raitem_rahead_id=:rahead_id) "
+                    " AND (raitem_status <> 'C'));");
+  openClose.bindValue(":rahead_id", _ra->id());
+  openClose.exec();
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Closing Return Auth."),
+                           openClose, __FILE__, __LINE__))
+  {
+    return;
+  }
+ 
+  omfgThis->sReturnAuthorizationsUpdated();
+}
+
 void openReturnAuthorizations::sDelete()
 {
   XSqlQuery openDelete;
@@ -182,13 +205,15 @@ void openReturnAuthorizations::sDelete()
       openDelete.exec();
       if (openDelete.lastError().type() != QSqlError::NoError)
       {
-        systemError(this, openDelete.lastError().databaseText(), __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Return Authorization"),
+                             openDelete, __FILE__, __LINE__);
       }
     }
   }
   else if (checkwo.lastError().type() != QSqlError::NoError)
   {
-    systemError(this, checkwo.lastError().databaseText(), __FILE__, __LINE__);
+    ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Return Authorization"),
+                         checkwo, __FILE__, __LINE__);
   }
   else
   {
@@ -201,7 +226,8 @@ void openReturnAuthorizations::sDelete()
       openDelete.exec();
       if (openDelete.lastError().type() != QSqlError::NoError)
       {
-        systemError(this, openDelete.lastError().databaseText(), __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Return Authorization"),
+                             openDelete, __FILE__, __LINE__);
       }
     }
   }
@@ -217,6 +243,9 @@ void openReturnAuthorizations::sPopulateMenu(QMenu *pMenu)
 
   menuItem = pMenu->addAction(tr("View..."), this, SLOT(sView()));
 
+  menuItem = pMenu->addAction(tr("Close..."), this, SLOT(sCloseRA()));
+  menuItem->setEnabled(_privileges->check("MaintainReturns"));
+
   menuItem = pMenu->addAction(tr("Delete..."), this, SLOT(sDelete()));
   menuItem->setEnabled(_privileges->check("MaintainReturns"));
 
@@ -235,9 +264,9 @@ void openReturnAuthorizations::sFillList()
   setParams(params);
   openFillList = mql.toQuery(params);
   _ra->populate(openFillList);
-  if (openFillList.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Return Authorization Information"),
+                                openFillList, __FILE__, __LINE__))
   {
-    systemError(this, openFillList.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
   _ra->setDragString("raheadid=");
