@@ -22,6 +22,7 @@
 #include "opportunity.h"
 #include "parameterwidget.h"
 #include "storedProcErrorLookup.h"
+#include "errorReporter.h"
 
 opportunityList::opportunityList(QWidget* parent, const char*, Qt::WindowFlags fl)
   : display(parent, "opportunityList", fl)
@@ -52,6 +53,7 @@ opportunityList::opportunityList(QWidget* parent, const char*, Qt::WindowFlags f
   list()->addColumn(tr("Currency"),    _currencyColumn, Qt::AlignLeft,   false, "f_currency" );
   list()->addColumn(tr("Target Date"), _dateColumn,     Qt::AlignLeft,   true, "ophead_target_date" );
   list()->addColumn(tr("Actual Date"), _dateColumn,     Qt::AlignLeft,   false, "ophead_actual_date" );
+  list()->addColumn(tr("Create Date"), _dateColumn,     Qt::AlignLeft,   false, "ophead_created" );
 
   connect(list(), SIGNAL(itemSelected(int)), this, SLOT(sOpen()));
 
@@ -70,6 +72,8 @@ opportunityList::opportunityList(QWidget* parent, const char*, Qt::WindowFlags f
   parameterWidget()->append(tr("Source Pattern"), "opsource_pattern",    ParameterWidget::Text);
   parameterWidget()->appendComboBox(tr("Stage"), "opstage_id", XComboBox::OpportunityStages);
   parameterWidget()->append(tr("Stage Pattern"), "opstage_pattern",    ParameterWidget::Text);
+  parameterWidget()->append(tr("Create Date on or After"), "startCreateDate", ParameterWidget::Date);
+  parameterWidget()->append(tr("Create Date on or Before"),   "endCreateDate",   ParameterWidget::Date);
 
   setupCharacteristics("OPP");
   parameterWidget()->applyDefaultFilterSet();
@@ -178,15 +182,17 @@ void opportunityList::sDelete()
     int result = opportunityDelete.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("deleteOpportunity", result));
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Opportunity"),
+                             storedProcErrorLookup("deleteOpportunity", result),
+                             __FILE__, __LINE__);
       return;
     }
     else
       sFillList();
     }
-  else if (opportunityDelete.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Opportunity"),
+                                opportunityDelete, __FILE__, __LINE__))
   {
-    systemError(this, opportunityDelete.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
@@ -199,7 +205,8 @@ void opportunityList::sDeactivate()
   opportunityDeactivate.bindValue(":ophead_id", list()->id());
   opportunityDeactivate.exec();
   if (opportunityDeactivate.lastError().type() != QSqlError::NoError)
-    systemError(this, opportunityDeactivate.lastError().databaseText(), __FILE__, __LINE__);
+    ErrorReporter::error(QtCriticalMsg, this, tr("Error Deactiving Opportunity"),
+                       opportunityDeactivate, __FILE__, __LINE__);
   else
     sFillList();
 }
@@ -211,7 +218,8 @@ void opportunityList::sActivate()
   opportunityActivate.bindValue(":ophead_id", list()->id());
   opportunityActivate.exec();
   if (opportunityActivate.lastError().type() != QSqlError::NoError)
-    systemError(this, opportunityActivate.lastError().databaseText(), __FILE__, __LINE__);
+    ErrorReporter::error(QtCriticalMsg, this, tr("Error Activating Opportunity"),
+                       opportunityActivate, __FILE__, __LINE__);
   else
     sFillList();
 }
@@ -229,20 +237,23 @@ bool opportunityList::setParams(ParameterList &params)
 
 void opportunityList::sOpen()
 {
-  bool editPriv =
-      (omfgThis->username() == list()->currentItem()->rawValue("ophead_owner_username") && _privileges->check("MaintainPersonalOpportunities")) ||
-      (omfgThis->username() == list()->currentItem()->rawValue("ophead_username") && _privileges->check("MaintainPersonalOpportunities")) ||
-      (_privileges->check("MaintainAllOpportunities"));
-
-  bool viewPriv =
-      (omfgThis->username() == list()->currentItem()->rawValue("ophead_owner_username") && _privileges->check("ViewPersonalOpportunities")) ||
-      (omfgThis->username() == list()->currentItem()->rawValue("ophead_username") && _privileges->check("ViewPersonalOpportunities")) ||
-      (_privileges->check("ViewAllOpportunities"));
-
-  if (editPriv)
-    sEdit();
-  else if (viewPriv)
-    sView();
+  if (list()->id() > 0)
+  {
+    bool editPriv =
+    (omfgThis->username() == list()->currentItem()->rawValue("ophead_owner_username") && _privileges->check("MaintainPersonalOpportunities")) ||
+    (omfgThis->username() == list()->currentItem()->rawValue("ophead_username") && _privileges->check("MaintainPersonalOpportunities")) ||
+    (_privileges->check("MaintainAllOpportunities"));
+    
+    bool viewPriv =
+    (omfgThis->username() == list()->currentItem()->rawValue("ophead_owner_username") && _privileges->check("ViewPersonalOpportunities")) ||
+    (omfgThis->username() == list()->currentItem()->rawValue("ophead_username") && _privileges->check("ViewPersonalOpportunities")) ||
+    (_privileges->check("ViewAllOpportunities"));
+    
+    if (editPriv)
+      sEdit();
+    else if (viewPriv)
+      sView();
+  }
 }
 
 
