@@ -13,6 +13,8 @@
 #include <QVariant>
 #include <QMessageBox>
 
+#include "errorReporter.h"
+
 /*
  *  Constructs a opportunityType as a child of 'parent', with the
  *  name 'name' and widget flags set to 'f'.
@@ -129,9 +131,8 @@ void opportunityType::sSave()
       _optypeid = opportunitySave.value("optype_id").toInt();
     else
     {
-      systemError(this, tr("A System Error occurred at %1::%2.")
-                        .arg(__FILE__)
-                        .arg(__LINE__) );
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Opportunity Type"),
+                           opportunitySave, __FILE__, __LINE__);
       return;
     }
 
