@@ -21,7 +21,7 @@ class opportunityType : public XDialog, public Ui::opportunityType
     Q_OBJECT
 
 public:
-    opportunityType(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    opportunityType(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~opportunityType();
 
     virtual void populate();
