@@ -21,6 +21,7 @@
 
 #include "package.h"
 #include "storedProcErrorLookup.h"
+#include "errorReporter.h"
 
 packages::packages(QWidget* parent, const char* name, Qt::WindowFlags fl)
     : XWidget(parent, name, fl)
@@ -85,9 +86,9 @@ void packages::sFillList()
              "ORDER BY pkghead_name, pkghead_version DESC;" );
   packagesFillList.exec();
   _package->populate(packagesFillList);
-  if (packagesFillList.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Package Information"),
+                                packagesFillList, __FILE__, __LINE__))
   {
-    systemError(this, packagesFillList.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
@@ -112,14 +113,15 @@ void packages::sDelete()
     int result = packagesDelete.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("deletePackage", result),
-                  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Package Information"),
+                             storedProcErrorLookup("deletePackage", result),
+                             __FILE__, __LINE__);
       return;
     }
   }
-  else if (packagesDelete.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Package"),
+                                packagesDelete, __FILE__, __LINE__))
   {
-    systemError(this, packagesDelete.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
@@ -198,12 +200,13 @@ void packages::sLoad()
       proc_args << "-passwd=XXXXX";
     }
     QApplication::restoreOverrideCursor();
-    systemError(this,
-                tr("<p>There was an error running the Updater program: "
-                   "<br>%1 %2<br><br><pre>%3</pre>")
-		  .arg(proc_path)
-                  .arg(proc_args.join(" "))
-		  .arg(QString(proc.readAllStandardError())));
+    ErrorReporter::error(QtCriticalMsg, this, tr("Error Occurred"),
+                         tr("%1: There was an error running the Updater program: "
+                            "<br>%2 %3<br><br><pre>%4</pre>")
+                         .arg(windowTitle())
+                         .arg(proc_path)
+                         .arg(proc_args.join(" "))
+                         .arg(QString(proc.readAllStandardError())),__FILE__,__LINE__);
     return;
   }
 
@@ -290,15 +293,15 @@ void packages::sEnable()
     int result = eq.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("enablePackage", result)
-                          .arg(_package->id()),
-                  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Enabling Package"),
+                             storedProcErrorLookup("enablePackage", result),
+                             __FILE__, __LINE__);
       return;
     }
   }
-  else if (eq.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Enabling Package"),
+                                eq, __FILE__, __LINE__))
   {
-    systemError(this, eq.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
   sFillList();
@@ -315,15 +318,15 @@ void packages::sDisable()
     int result = dq.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("disablePackage", result)
-                          .arg(_package->id()),
-                  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Disabling Package"),
+                             storedProcErrorLookup("disablePackage", result),
+                             __FILE__, __LINE__);
       return;
     }
   }
-  else if (dq.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Disabling Package"),
+                                dq, __FILE__, __LINE__))
   {
-    systemError(this, dq.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
   sFillList();
