@@ -21,7 +21,7 @@ class printLabelsByOrder : public XDialog, public Ui::printLabelsByOrder
     Q_OBJECT
 
 public:
-    printLabelsByOrder(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    printLabelsByOrder(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~printLabelsByOrder();
 
 public slots:
