@@ -19,7 +19,7 @@ class projects : public display, public Ui::projects
     Q_OBJECT
 
 public:
-    projects(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    projects(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 public slots:
     virtual void sNew();
