@@ -24,6 +24,7 @@ public:
     ~registrationKeyDialog();
 
 public slots:
+    virtual enum SetResponse set(const ParameterList & pParams );
     virtual void sCheckKey();
     virtual void sSelect();
     virtual void sClose();
@@ -31,6 +32,9 @@ public slots:
 protected slots:
     virtual void languageChange();
 
+protected:
+    virtual void closeEvent(QCloseEvent*);
+
 private:
     int _bankaccntid;
     QString _type;
