@@ -14,6 +14,7 @@
 #include <QSqlError>
 
 #include "storedProcErrorLookup.h"
+#include "errorReporter.h"
 
 resetQOHBalances::resetQOHBalances(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl)
@@ -77,14 +78,15 @@ void resetQOHBalances::sReset()
     int result = resetReset.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("resetQOHBalance", result),
-                  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Resetting QOH Balance"),
+                             storedProcErrorLookup("resetQOHBalance", result),
+                             __FILE__, __LINE__);
       return;
     }
   }
-  else if (resetReset.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Resetting QOH Balance"),
+                                resetReset, __FILE__, __LINE__))
   {
-    systemError(this, resetReset.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
