@@ -22,6 +22,7 @@
 #include "selectBillingQty.h"
 #include "storedProcErrorLookup.h"
 #include "taxBreakdown.h"
+#include "errorReporter.h"
 
 selectOrderForBilling::selectOrderForBilling(QWidget* parent, const char* name, Qt::WindowFlags fl)
     : XWidget(parent, name, fl)
@@ -225,10 +226,10 @@ void selectOrderForBilling::sSave()
     selectSave.bindValue(":cobmisc_misc_descrip", _miscChargeDescription->text().trimmed());
     selectSave.bindValue(":cobmisc_curr_id",	_custCurrency->id());
     selectSave.exec();
-    if (selectSave.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Saving Selected Orders For Billing"),
+                                  selectSave, __FILE__, __LINE__))
     {
-	systemError(this, selectSave.lastError().databaseText(), __FILE__, __LINE__);
-	return;
+      return;
     }
   }
 
@@ -249,7 +250,7 @@ void selectOrderForBilling::sSoList()
   params.append("sohead_id", _so->id());
 
   if (_showClosed->isChecked())
-    params.append("soType", (cSoOpen || cSoClosed));
+    params.append("soType", (cSoOpen | cSoClosed));
   else
     params.append("soType", cSoOpen);
 
@@ -274,14 +275,15 @@ void selectOrderForBilling::sPopulate(int pSoheadid)
       _cobmiscid = selectPopulate.value("cobmisc_id").toInt();
       if (_cobmiscid < 0)
       {
-	systemError(this, storedProcErrorLookup("createBillingHeader", _cobmiscid),
-		    __FILE__, __LINE__);
-	return;
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Sales Order Information"),
+                               storedProcErrorLookup("createBillingHeader", _cobmiscid),
+                               __FILE__, __LINE__);
+        return;
       }
     }
-    else if (selectPopulate.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Sales Order Information"),
+                                  selectPopulate, __FILE__, __LINE__))
     {
-      systemError(this, selectPopulate.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
 
@@ -344,9 +346,9 @@ void selectOrderForBilling::sPopulate(int pSoheadid)
         _freight->clear();
       }
     }
-    else if (selectPopulate.lastError().type() != QSqlError::NoError)
+    else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Billing Selection Information"),
+                                  selectPopulate, __FILE__, __LINE__))
     {
-      systemError(this, selectPopulate.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
   }
@@ -404,14 +406,15 @@ void selectOrderForBilling::sSelectBalance()
     int result = selectSelectBalance.value("result").toInt();
     if (result < 0)
     {
-      systemError(this, storedProcErrorLookup("selectBalanceForBilling", result),
-		  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Billing Information"),
+                             storedProcErrorLookup("selectBalanceForBilling", result),
+                             __FILE__, __LINE__);
       return;
     }
   }
-  else if (selectSelectBalance.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Billing Information"),
+                                selectSelectBalance, __FILE__, __LINE__))
   {
-    systemError(this, selectSelectBalance.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
@@ -431,9 +434,9 @@ void selectOrderForBilling::sCalculateTax()
   taxq.exec();
   if (taxq.first())
     _salesTax->setLocalValue(taxq.value("tax").toDouble());
-  else if (taxq.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Tax Information"),
+                                taxq, __FILE__, __LINE__))
   {
-    systemError(this, taxq.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
   // changing _tax fires sCalculateTotal()
@@ -520,7 +523,8 @@ void selectOrderForBilling::sFillList()
     else
     {
       if (selectFillList.lastError().type() != QSqlError::NoError)
-	systemError(this, selectFillList.lastError().databaseText(), __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Billing Information"),
+                           selectFillList, __FILE__, __LINE__);
       _subtotal->clear();
     }
 
@@ -546,9 +550,9 @@ void selectOrderForBilling::sHandleShipchrg(int pShipchrgid)
       _freight->clear();
     }
   }
-  else if (query.lastError().type() != QSqlError::NoError)
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Retrieving Shipping Charge Information"),
+                                query, __FILE__, __LINE__))
   {
-    systemError(this, query.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
@@ -566,9 +570,9 @@ void selectOrderForBilling::sTaxDetail()
   taxq.bindValue(":cobmisc_id",	_cobmiscid);
   taxq.bindValue(":invcdate",   _invoiceDate->date());
   taxq.exec();
-  if (taxq.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Updating Tax Information"),
+                                taxq, __FILE__, __LINE__))
   {
-    systemError(this, taxq.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 
@@ -595,11 +599,13 @@ void selectOrderForBilling::closeEvent(QCloseEvent * pEvent)
   {
     int result = selectcloseEvent.value("result").toInt();
     if (result < -2) // don't bother the user with -1:posted or -2:has-lines
-      systemError(this, storedProcErrorLookup("releaseUnusedBillingHeader", result),
-		  __FILE__, __LINE__);
+      ErrorReporter::error(QtCriticalMsg, this, tr("Error Releasing Unused Billing Header"),
+                             storedProcErrorLookup("releaseUnusedBillingHeader", result),
+                             __FILE__, __LINE__);
   }
   else if (selectcloseEvent.lastError().type() != QSqlError::NoError)
-    systemError(this, selectcloseEvent.lastError().databaseText(), __FILE__, __LINE__);
+    ErrorReporter::error(QtCriticalMsg, this, tr("Error Releasing Unused Billing Header"),
+                       selectcloseEvent, __FILE__, __LINE__);
 
   XWidget::closeEvent(pEvent);
 }
@@ -617,9 +623,9 @@ void selectOrderForBilling::sTaxZoneChanged()
     taxq.bindValue(":cobmisc_id", _cobmiscid);
     taxq.bindValue(":freight", _freight->localValue());
     taxq.exec();
-    if (taxq.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Updating Tax Information"),
+                                  taxq, __FILE__, __LINE__))
     {
-      systemError(this, taxq.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
     _taxzoneidCache = _taxZone->id();
@@ -638,9 +644,9 @@ void selectOrderForBilling::sFreightChanged()
     taxq.bindValue(":cobmisc_id", _cobmiscid);
     taxq.bindValue(":freight", _freight->localValue());
     taxq.exec();
-    if (taxq.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Updating Freight Information"),
+                                          taxq, __FILE__, __LINE__))
     {
-      systemError(this, taxq.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
     _freightCache = _freight->localValue();
