@@ -1,7 +1,7 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2016 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
@@ -25,6 +25,7 @@
 #include "getGLDistDate.h"
 #include "printCreditMemo.h"
 #include "storedProcErrorLookup.h"
+#include "errorReporter.h"
 
 unpostedCreditMemos::unpostedCreditMemos(QWidget* parent, const char* name, Qt::WindowFlags fl)
     : XWidget(parent, name, fl)
@@ -39,10 +40,10 @@ unpostedCreditMemos::unpostedCreditMemos(QWidget* parent, const char* name, Qt::
     connect(_print, SIGNAL(clicked()), this, SLOT(sPrint()));
     connect(_post, SIGNAL(clicked()), this, SLOT(sPost()));
 
-    _cmhead->addColumn(tr("Return #"),      _orderColumn, Qt::AlignLeft,   true,  "cmhead_number"   );
+    _cmhead->addColumn(tr("Sales Credit #"),      _orderColumn, Qt::AlignLeft,   true,  "cmhead_number"   );
     _cmhead->addColumn(tr("Prnt'd"),        _orderColumn, Qt::AlignCenter, true,  "printed" );
     _cmhead->addColumn(tr("Customer"),      -1,           Qt::AlignLeft,   true,  "cmhead_billtoname"   );
-    _cmhead->addColumn(tr("Return Date"),   _dateColumn,  Qt::AlignCenter, true,  "cmhead_docdate" );
+    _cmhead->addColumn(tr("Credit Date"),   _dateColumn,  Qt::AlignCenter, true,  "cmhead_docdate" );
     _cmhead->addColumn(tr("Hold"),          _whsColumn,   Qt::AlignCenter, true,  "cmhead_hold" );
     _cmhead->addColumn(tr("G/L Dist Date"), _dateColumn,  Qt::AlignCenter, true,  "distdate" );
 
@@ -172,7 +173,7 @@ void unpostedCreditMemos::sPost()
   if (_privileges->check("ChangeSOMemoPostDate"))
   {
     getGLDistDate newdlg(this, "", true);
-    newdlg.sSetDefaultLit(tr("Return Date"));
+    newdlg.sSetDefaultLit(tr("Credit Memo Date"));
     if (newdlg.exec() == XDialog::Accepted)
     {
       newDate = newdlg.date();
@@ -200,9 +201,10 @@ void unpostedCreditMemos::sPost()
         setDate.bindValue(":distdate",  newDate);
         setDate.bindValue(":cmhead_id", id);
         setDate.exec();
-        if (setDate.lastError().type() != QSqlError::NoError)
+        if (ErrorReporter::error(QtCriticalMsg, this, tr("Error Posting Credit Memo Information"),
+                                      setDate, __FILE__, __LINE__))
         {
-	      systemError(this, setDate.lastError().databaseText(), __FILE__, __LINE__);
+          return;
         }
       }
     }
@@ -233,8 +235,9 @@ void unpostedCreditMemos::sPost()
           if (result < 0)
           {
             rollback.exec();
-            systemError( this, storedProcErrorLookup("postCreditMemo", result),
-                  __FILE__, __LINE__);
+            ErrorReporter::error(QtCriticalMsg, this, tr("Error Posting Credit Memo Information"),
+                                 storedProcErrorLookup("postCreditMemo", result),
+                                 __FILE__, __LINE__);
             return;
           }
           else
@@ -242,7 +245,7 @@ void unpostedCreditMemos::sPost()
             if (distributeInventory::SeriesAdjust(result, this) == XDialog::Rejected)
             {
               rollback.exec();
-              QMessageBox::information( this, tr("Post Return"), tr("Transaction Canceled") );
+              QMessageBox::information( this, tr("Post Sales Credit"), tr("Transaction Canceled") );
               return;
             }
 
@@ -264,10 +267,10 @@ void unpostedCreditMemos::sPost()
         else if (postq.lastError().type() != QSqlError::NoError)
         {
           rollback.exec();
-          systemError(this, tr("A System Error occurred posting Return#%1.\n%2")
-                  .arg(selected[i]->text(0))
-                  .arg(postq.lastError().databaseText()),
-                __FILE__, __LINE__);
+          ErrorReporter::error(QtCriticalMsg, this, tr("Error Posting Credit Memo Information: %1 \n%2")
+                               .arg(selected[i]->text(0))
+                               .arg(postq.lastError().databaseText()),
+                               postq, __FILE__, __LINE__);
         }
       }
 
@@ -287,9 +290,9 @@ void unpostedCreditMemos::sPost()
 
 void unpostedCreditMemos::sDelete()
 {
-  if (QMessageBox::question(this, tr("Delete Selected Returns?"),
+  if (QMessageBox::question(this, tr("Delete Selected Sales Credits?"),
                             tr("<p>Are you sure that you want to delete the "
-			       "selected Returns?"),
+			       "selected Sales Credits?"),
                             QMessageBox::Yes, QMessageBox::No | QMessageBox::Default) == QMessageBox::Yes)
   {
     XSqlQuery delq;
@@ -304,14 +307,16 @@ void unpostedCreditMemos::sDelete()
         delq.exec();
         if (delq.first())
         {
-	      if (! delq.value("result").toBool())
-	        systemError(this, tr("Could not delete Return."),
-		            __FILE__, __LINE__);
+          int result = delq.value("result").toInt();
+          if (result < 0)
+            ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Credit Memo Information"),
+                                 storedProcErrorLookup("deleteCreditMemo", result),
+                                 __FILE__, __LINE__);
         }
         else if (delq.lastError().type() != QSqlError::NoError)
-	      systemError(this,
-		          tr("Error deleting Return %1\n").arg(selected[i]->text(0)) +
-		          delq.lastError().databaseText(), __FILE__, __LINE__);
+          ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Credit Memo Information %1\n")
+                             .arg(selected[i]->text(0)) + delq.lastError().databaseText(),
+                             delq, __FILE__, __LINE__);
       }
     }
 
@@ -335,6 +340,10 @@ void unpostedCreditMemos::sFillList()
                      "              AND   (warehous_id=itemsite_warehous_id) )) > 0) OR"
                      "          ((SELECT COUNT(*)"
                      "            FROM cmitem"
+                     "            WHERE ((cmitem_cmhead_id=cmhead_id)"
+                     "              AND  (cmitem_number IS NOT NULL) )) > 0) OR"
+                     "          ((SELECT COUNT(*)"
+                     "            FROM cmitem"
                      "            WHERE (cmitem_cmhead_id=cmhead_id)) = 0) ) ) "
                      "ORDER BY cmhead_number;" );
 }
@@ -352,7 +361,7 @@ bool unpostedCreditMemos::checkSitePrivs(int orderid)
     if (!check.value("result").toBool())
       {
         QMessageBox::critical(this, tr("Access Denied"),
-                                       tr("You may not view or edit this Return as it references "
+                                       tr("You may not view or edit this Sales Credit as it references "
                                        "a Site for which you have not been granted privileges.")) ;
         return false;
       }
