@@ -21,9 +21,11 @@
 
 #include "purchaseOrder.h"
 #include "printPurchaseOrder.h"
+#include "printPoForm.h"
 #include "guiclient.h"
 #include "storedProcErrorLookup.h"
 #include "parameterwidget.h"
+#include "errorReporter.h"
 
 unpostedPurchaseOrders::unpostedPurchaseOrders(QWidget* parent, const char*, Qt::WindowFlags fl)
   : display(parent, "unpostedPurchaseOrders", fl)
@@ -167,13 +169,16 @@ void unpostedPurchaseOrders::sDelete()
           unpostedDelete.bindValue(":pohead_id", ((XTreeWidgetItem*)(selected[i]))->id());
           unpostedDelete.exec();
           if (unpostedDelete.first() && ! unpostedDelete.value("result").toBool())
-              systemError(this, tr("<p>Only Unposted Purchase Orders may be "
-                                   "deleted. Check the status of Purchase Order "
-                                   "%1. If it is 'U' then contact your system "
-                                   "Administrator.").arg(selected[i]->text(0)),
-                          __FILE__, __LINE__);
+              ErrorReporter::error(QtCriticalMsg, this, tr("Error Occurred"),
+                               tr("%1: <p>Only Unposted Purchase Orders may be "
+                                  "deleted. Check the status of Purchase Order "
+                                  "%2. If it is 'U' then contact your system "
+                                  "Administrator.")
+                                   .arg(windowTitle())
+                                   .arg(selected[i]->text(0)),__FILE__,__LINE__);
           else if (unpostedDelete.lastError().type() != QSqlError::NoError)
-            systemError(this, unpostedDelete.lastError().databaseText(), __FILE__, __LINE__);
+            ErrorReporter::error(QtCriticalMsg, this, tr("Error Deleting Purchase Order"),
+                               unpostedDelete, __FILE__, __LINE__);
           else
             done = true;
         }
@@ -208,6 +213,24 @@ void unpostedPurchaseOrders::sPrint()
   sFillList();
 }
 
+void unpostedPurchaseOrders::sPrintForms()
+{
+  QList<XTreeWidgetItem*> selected = list()->selectedItems();
+  for (int i = 0; i < selected.size(); i++)
+  {
+    if (checkSitePrivs(((XTreeWidgetItem*)(selected[i]))->id()))
+    { 
+      ParameterList params;
+      params.append("pohead_id", list()->id());
+
+      printPoForm newdlg(this, "", true);
+      newdlg.set(params);
+      newdlg.exec();
+      break;
+    }
+  }
+}
+
 void unpostedPurchaseOrders::sRelease()
 {
   XSqlQuery unpostedRelease;
@@ -227,13 +250,15 @@ void unpostedPurchaseOrders::sRelease()
       {
         int result = unpostedRelease.value("result").toInt();
         if (result < 0)
-          systemError(this, storedProcErrorLookup("releasePurchaseOrder", result),
-                      __FILE__, __LINE__);
+          ErrorReporter::error(QtCriticalMsg, this, tr("Error Releasing Purchase Order"),
+                                 storedProcErrorLookup("releasePurchaseOrder", result),
+                                 __FILE__, __LINE__);
         else
           done = true;
       }
       else if (unpostedRelease.lastError().type() != QSqlError::NoError)
-        systemError(this, unpostedRelease.lastError().databaseText(), __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Releasing Purchase Order"),
+                           unpostedRelease, __FILE__, __LINE__);
     }
   }
   if (done)
@@ -264,13 +289,15 @@ void unpostedPurchaseOrders::sUnrelease()
       {
         int result = unRelease.value("result").toInt();
         if (result < 0)
-          systemError(this, storedProcErrorLookup("unreleasePurchaseOrder", result),
-                      __FILE__, __LINE__);
+          ErrorReporter::error(QtCriticalMsg, this, tr("Error Unreleasing Purchase Order"),
+                                 storedProcErrorLookup("unreleasePurchaseOrder", result),
+                                 __FILE__, __LINE__);
         else
           done = true;
       }
       else if (unRelease.lastError().type() != QSqlError::NoError)
-        systemError(this, unRelease.lastError().databaseText(), __FILE__, __LINE__);
+        ErrorReporter::error(QtCriticalMsg, this, tr("Error Unreleasing Purchase Order"),
+                           unRelease, __FILE__, __LINE__);
     }
   }
   if (done)
@@ -294,6 +321,9 @@ void unpostedPurchaseOrders::sPopulateMenu(QMenu *pMenu, QTreeWidgetItem *pItem,
   menuItem = pMenu->addAction(tr("Print..."), this, SLOT(sPrint()));
   menuItem->setEnabled(_privileges->check("PrintPurchaseOrders"));
 
+  menuItem = pMenu->addAction(tr("Print Purchase Order Forms..."), this, SLOT(sPrintForms())); 
+  menuItem->setEnabled(_privileges->check("PrintPurchaseOrders"));
+
   pMenu->addSeparator();
 
   menuItem = pMenu->addAction(tr("Edit..."), this, SLOT(sEdit()));
