@@ -19,7 +19,7 @@ class vendors : public display
     Q_OBJECT
 
 public:
-    vendors(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    vendors(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 public slots:
     virtual void sNew();
