@@ -21,7 +21,7 @@ class warehouseZone : public XDialog, public Ui::warehouseZone
     Q_OBJECT
 
 public:
-    warehouseZone(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    warehouseZone(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~warehouseZone();
 
 public slots:
