@@ -1,7 +1,7 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2016 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
@@ -11,6 +11,7 @@
 #include "addressclustersetup.h"
 #include "alarmssetup.h"
 #include "calendarTools.h"
+#include "char.h"
 #include "clineeditsetup.h"
 #include "commentssetup.h"
 #include "contactwidgetsetup.h"
@@ -18,11 +19,14 @@
 #include "currdisplaysetup.h"
 #include "documentssetup.h"
 #include "empcluster.h"
+#include "engineevaluate.h"
 #include "exporthelper.h"
 #include "filemoveselector.h"
 #include "glclustersetup.h"
 #include "include.h"
 #include "itemlineeditsetup.h"
+#include "itemgroupcluster.h"
+#include "jsconsole.h"
 #include "metasqlhighlighterproto.h"
 #include "orderlineeditsetup.h"
 #include "orreportproto.h"
@@ -31,13 +35,24 @@
 #include "parameterlistsetup.h"
 #include "parameterwidget.h"
 #include "projectlineeditsetup.h"
+#include "qabstractsocketproto.h"
 #include "qactionproto.h"
 #include "qapplicationproto.h"
 #include "qboxlayoutproto.h"
+#include "qbufferproto.h"
+#include "qbuttongroupproto.h"
 #include "qbytearrayproto.h"
+#include "qcoreapplicationproto.h"
+#include "qcryptographichashproto.h"
 #include "qdialogsetup.h"
 #include "qdialogbuttonboxproto.h"
 #include "qdirproto.h"
+#include "qdnsdomainnamerecordproto.h"
+#include "qdnshostaddressrecordproto.h"
+#include "qdnslookupproto.h"
+#include "qdnsmailexchangerecordproto.h"
+#include "qdnsservicerecordproto.h"
+#include "qdnstextrecordproto.h"
 #include "qdockwidgetproto.h"
 #include "qdomattrproto.h"
 #include "qdomcdatasectionproto.h"
@@ -57,6 +72,8 @@
 #include "qdomprocessinginstructionproto.h"
 #include "qdomtextproto.h"
 #include "qdoublevalidatorproto.h"
+#include "qhostaddressproto.h"
+#include "qhostinfoproto.h"
 #include "qintvalidatorproto.h"
 #include "qeventproto.h"
 #include "qfileproto.h"
@@ -67,24 +84,48 @@
 #include "qiconproto.h"
 #include "qiodeviceproto.h"
 #include "qitemdelegateproto.h"
+#include "qjsondocumentproto.h"
+#include "qjsonobjectproto.h"
+#include "qjsonvalueproto.h"
 #include "qlayoutitemproto.h"
 #include "qlayoutproto.h"
 #include "qmainwindowproto.h"
 #include "qmenuproto.h"
+#include "qmenubarproto.h"
 #include "qmessageboxsetup.h"
+#include "qnetworkaccessmanagerproto.h"
+#include "qnetworkinterfaceproto.h"
 #include "qnetworkreplyproto.h"
 #include "qnetworkrequestproto.h"
+#include "qobjectproto.h"
 #include "qprinterproto.h"
 #include "qprocessproto.h"
 #include "qprocessenvironmentproto.h"
 #include "qpushbuttonproto.h"
+#include "qserialportproto.h"
+#include "qserialportinfoproto.h"
 #include "qsizepolicyproto.h"
 #include "qspaceritemproto.h"
+#include "qsqlproto.h"
 #include "qsqldatabaseproto.h"
+#include "qsqldriverproto.h"
 #include "qsqlerrorproto.h"
+#include "qsqlqueryproto.h"
 #include "qsqlrecordproto.h"
+#include "qsslcertificateextensionproto.h"
+#include "qsslcertificateproto.h"
+#include "qsslcipherproto.h"
+#include "qsslconfigurationproto.h"
+#include "qsslellipticcurveproto.h"
+#include "qsslerrorproto.h"
+#include "qsslkeyproto.h"
+#include "qsslpresharedkeyauthenticatorproto.h"
+#include "qsslproto.h"
+#include "qsslsocketproto.h"
 #include "qstackedwidgetproto.h"
 #include "qtabwidgetproto.h"
+#include "qtcpserverproto.h"
+#include "qtcpsocketproto.h"
 #include "qtextdocumentproto.h"
 #include "qtexteditproto.h"
 #include "qtimerproto.h"
@@ -92,10 +133,23 @@
 #include "qtoolbuttonproto.h"
 #include "qtreewidgetitemproto.h"
 #include "qtsetup.h"
+#include "qudpsocketproto.h"
 #include "queryset.h"
 #include "qurlproto.h"
+#include "qurlqueryproto.h"
+#include "quuidproto.h"
 #include "qvalidatorproto.h"
+#include "qwebchannelproto.h"
+#include "qwebelementproto.h"
+#include "qwebelementcollectionproto.h"
+#include "qwebframeproto.h"
 #include "qwebpageproto.h"
+#include "qwebsecurityoriginproto.h"
+#include "qwebsettingsproto.h"
+#include "qwebsocketcorsauthenticatorproto.h"
+#include "qwebsocketproto.h"
+#include "qwebsocketprotocolproto.h"
+#include "qwebsocketserverproto.h"
 #include "qwebviewproto.h"
 #include "qwidgetproto.h"
 #include "ralineeditsetup.h"
@@ -107,6 +161,7 @@
 #include "usernamecluster.h"
 #include "vendorgroupsetup.h"
 #include "wcomboboxsetup.h"
+#include "webchanneltransport.h"
 #include "wocluster.h"
 #include "womatlclustersetup.h"
 #include "xcheckbox.h"
@@ -114,11 +169,11 @@
 #include "xdatawidgetmapperproto.h"
 #include "xdateeditsetup.h"
 #include "xdoccopysetter.h"
-#include "xnetworkaccessmanager.h"
 #include "xsqltablemodelproto.h"
 #include "xsqlqueryproto.h"
 #include "xtreewidget.h"
 #include "xvariantsetup.h"
+#include "xwebsync.h"
 
 /*! \defgroup scriptapi The xTuple ERP Scripting API
 
@@ -132,6 +187,7 @@ void setupScriptApi(QScriptEngine *engine)
   setupAddressCluster(engine);
   setupAlarms(engine);
   setupCLineEdit(engine);
+  setupchar(engine);
   setupCRMAcctLineEdit(engine);
   setupComments(engine);
   setupContactWidget(engine);
@@ -139,11 +195,14 @@ void setupScriptApi(QScriptEngine *engine)
   setupDocuments(engine);
   setupEmpCluster(engine);
   setupEmpClusterLineEdit(engine);
+  setupEngineEvaluate(engine);
   setupExportHelper(engine);
   setupFileMoveSelector(engine);
   setupGLCluster(engine);
   setupInclude(engine);
   setupItemLineEdit(engine);
+  setupItemGroupCluster(engine);
+  setupJSConsole(engine);
   setupMetaSQLHighlighterProto(engine);
   setupOrderLineEdit(engine);
   setupOrReportProto(engine);
@@ -153,13 +212,24 @@ void setupScriptApi(QScriptEngine *engine)
   setupParameterWidget(engine);
   setupPeriodListViewItem(engine);
   setupProjectLineEdit(engine);
+  setupQAbstractSocketProto(engine);
   setupQActionProto(engine);
   setupQApplicationProto(engine);
   setupQBoxLayoutProto(engine);
+  setupQBufferProto(engine);
+  setupQButtonGroupProto(engine);
   setupQByteArrayProto(engine);
+  setupQCoreApplicationProto(engine);
+  setupQCryptographicHashProto(engine);
   setupQDialog(engine);
   setupQDialogButtonBoxProto(engine);
   setupQDirProto(engine);
+  setupQDnsDomainNameRecordProto(engine);
+  setupQDnsHostAddressRecordProto(engine);
+  setupQDnsLookupProto(engine);
+  setupQDnsMailExchangeRecordProto(engine);
+  setupQDnsServiceRecordProto(engine);
+  setupQDnsTextRecordProto(engine);
   setupQDockWidgetProto(engine);
   setupQDomAttrProto(engine);
   setupQDomCDATASectionProto(engine);
@@ -186,28 +256,53 @@ void setupScriptApi(QScriptEngine *engine)
   setupQFontProto(engine);
   setupQFormLayoutProto(engine);
   setupQGridLayoutProto(engine);
+  setupQHostAddressProto(engine);
+  setupQHostInfoProto(engine);
   setupQIconProto(engine);
   setupQIODeviceProto(engine);
   setupQItemDelegateProto(engine);
+  setupQJsonDocumentProto(engine);
+  setupQJsonObjectProto(engine);
+  setupQJsonValueProto(engine);
   setupQLayoutItemProto(engine);
   setupQLayoutProto(engine);
   setupQMainWindowProto(engine);
   setupQMenuProto(engine);
+  setupQMenuBarProto(engine);
   setupQMessageBox(engine);
   setupQNetworkAccessManagerProto(engine);
+  setupQNetworkInterfaceProto(engine);
   setupQNetworkReplyProto(engine);
   setupQNetworkRequestProto(engine);
+  setupQObjectProto(engine);
   setupQPrinterProto(engine);
   setupQProcessProto(engine);
   setupQProcessEnvironmentProto(engine);
   setupQPushButtonProto(engine);
+  setupQSerialPortProto(engine);
+  setupQSerialPortInfoProto(engine);
   setupQSizePolicy(engine);
   setupQSpacerItem(engine);
+  setupQSqlProto(engine);
   setupQSqlDatabaseProto(engine);
+  setupQSqlDriverProto(engine);
   setupQSqlErrorProto(engine);
+  setupQSqlQueryProto(engine);
   setupQSqlRecordProto(engine);
+  setupQSslCertificateExtensionProto(engine);
+  setupQSslCertificateProto(engine);
+  setupQSslCipherProto(engine);
+  setupQSslConfigurationProto(engine);
+  setupQSslEllipticCurveProto(engine);
+  setupQSslErrorProto(engine);
+  setupQSslKeyProto(engine);
+  setupQSslPreSharedKeyAuthenticatorProto(engine);
+  setupQSslProto(engine);
+  setupQSslSocketProto(engine);
   setupQStackedWidgetProto(engine);
   setupQTabWidgetProto(engine);
+  setupQTcpServerProto(engine);
+  setupQTcpSocketProto(engine);
   setupQTextDocumentProto(engine);
   setupQTextEditProto(engine);
   setupQTimerProto(engine);
@@ -215,10 +310,23 @@ void setupScriptApi(QScriptEngine *engine)
   setupQToolButtonProto(engine);
   setupQTreeWidgetItemProto(engine);
   setupQt(engine);
+  setupQUdpSocketProto(engine);
   setupQuerySet(engine);
   setupQUrlProto(engine);
+  setupQUrlQueryProto(engine);
+  setupQUuidProto(engine);
   setupQValidatorProto(engine);
+  setupQWebChannelProto(engine);
+  setupQWebElementProto(engine);
+  setupQWebElementCollectionProto(engine);
+  setupQWebFrameProto(engine);
   setupQWebPageProto(engine);
+  setupQWebSecurityOriginProto(engine);
+  setupQWebSettingsProto(engine);
+  setupQWebSocketCorsAuthenticatorProto(engine);
+  setupQWebSocketProto(engine);
+  setupQWebSocketProtocolProto(engine);
+  setupQWebSocketServerProto(engine);
   setupQWebViewProto(engine);
   setupQWidgetProto(engine);
   setupRaLineEdit(engine);
@@ -230,6 +338,7 @@ void setupScriptApi(QScriptEngine *engine)
   setupUsernameLineEdit(engine);
   setupVendorGroup(engine);
   setupWComboBox(engine);
+  setupWebChannelTransport(engine);
   setupWoCluster(engine);
   setupWomatlCluster(engine);
   setupXCheckBox(engine);
@@ -243,4 +352,5 @@ void setupScriptApi(QScriptEngine *engine)
   setupXTreeWidget(engine);
   setupXTreeWidgetItem(engine);
   setupXVariant(engine);
+  setupXWebSync(engine);
 }
