@@ -1,7 +1,7 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2016 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
@@ -102,9 +102,10 @@ friend class WoCluster;
     Q_INVOKABLE inline int     warehouse() const              { return _warehouseid;         }
 
   public slots:
-    void silentSetId(const int);
-    void sList();
-    void sSearch();
+    virtual void clear();
+    virtual void silentSetId(const int);
+    virtual void sList();
+    virtual void sSearch();
 
   private:
     void init();
@@ -123,7 +124,6 @@ friend class WoCluster;
     woSearch* searchFactory();
 
   signals:
-    void newId(int);
     void newItemid(int);
     void warehouseChanged(const QString &);
     void itemNumberChanged(const QString &);
@@ -137,7 +137,6 @@ friend class WoCluster;
     void qtyBalanceChanged(const double);
     void statusChanged(const QString &);
     void methodChanged(const QString &);
-    void valid(bool);
 };
 
 class XTUPLEWIDGETS_EXPORT WoCluster : public QWidget
